// ============================================================================
// File:               IntFunction2
//
// Project:            CAFF
//
// Purpose:            
//
// Author:             Rammi
//
// Copyright Notice:   © 2020-2023  Rammi (rammi@caff.de)
//                     The usage of this source code in commercial or open 
//                     source projects is not allowed without explicit 
//                     permission.
//
// Created:            27.11.20 13:37
//=============================================================================
package de.caff.generics.function;

import de.caff.annotation.NotNull;

import java.util.function.IntToDoubleFunction;

/**
 * Function with two primitive integer arguments and a primitive double result.
 * @author <a href="mailto:rammi@caff.de">Rammi</a>
 * @since November 27, 2020
 */
@FunctionalInterface
public interface IntToDoubleFunction2
{
  /**
   * Apply this function to the given 2 arguments.
   * @param value1 first argument
   * @param value2 second argument
   * @return the function result
   */
  double applyAsDouble(int value1, int value2);

  /**
   * View this function as one with 1 argument using a fix first argument.
   * @param value1 fix first argument
   * @return function expecting the remaining argument
   */
  @NotNull
  default IntToDoubleFunction partial1(int value1)
  {
    return v2 -> applyAsDouble(value1, v2);
  }

  /**
   * View this function as one with 1 argument using a fix second argument.
   * @param value2 fix second argument
   * @return function expecting the remaining argument
   */
  @NotNull
  default IntToDoubleFunction partial2(int value2)
  {
    return v1 -> applyAsDouble(v1, value2);
  }

}
