// ============================================================================
// COPYRIGHT NOTICE
// ----------------------------------------------------------------------------
// (This is the open source ISC license, see
// http://en.wikipedia.org/wiki/ISC_license
// for more info)
//
// Copyright © 2021 - 2022  Andreas M. Rammelt <rammi@caff.de>
//
// Permission to use, copy, modify, and/or distribute this software for any
// purpose with or without fee is hereby granted, provided that the above
// copyright notice and this permission notice appear in all copies.
//
// THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
// WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
// ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
// WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
// ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
// OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
//=============================================================================
// Latest version on https://caff.de/projects/decaff-commons/
//=============================================================================
package de.caff.generics.tuple;

import de.caff.annotation.NotNull;
import de.caff.annotation.Nullable;

import java.io.Serializable;
import java.util.Objects;

/**
 * Immutable tuple with 9 non-null elements.
 *
 * If you want to iterate over a tuple or access its elements by index
 * (note that both is only possible for a common super type of the tuple's types)
 * {@link de.caff.generics.Indexable#viewTuple(ITuple9)} will come to help.
 *
 * Note that this class is automatically created by {@code tools.TupleClassCreator} (not yet public).
 *
 * @param <T1> type of first element
 * @param <T2> type of second element
 * @param <T3> type of third element
 * @param <T4> type of fourth element
 * @param <T5> type of fifth element
 * @param <T6> type of sixth element
 * @param <T7> type of seventh element
 * @param <T8> type of eighth element
 * @param <T9> type of nineth element
 * @author <a href="mailto:rammi@caff.de">Rammi</a>
 * @since November 17, 2021
 * @see NTuple9
 */
public class Tuple9<T1, T2, T3, T4, T5, T6, T7, T8, T9>
        extends ITuple9.Base<T1, T2, T3, T4, T5, T6, T7, T8, T9>
        implements Serializable
{
  private static final long serialVersionUID = 1L;

  @NotNull
  private final T1 elem1;
  @NotNull
  private final T2 elem2;
  @NotNull
  private final T3 elem3;
  @NotNull
  private final T4 elem4;
  @NotNull
  private final T5 elem5;
  @NotNull
  private final T6 elem6;
  @NotNull
  private final T7 elem7;
  @NotNull
  private final T8 elem8;
  @NotNull
  private final T9 elem9;

  /**
   * Constructor.
   * @param e1 first element
   * @param e2 second element
   * @param e3 third element
   * @param e4 fourth element
   * @param e5 fifth element
   * @param e6 sixth element
   * @param e7 seventh element
   * @param e8 eighth element
   * @param e9 nineth element
   */
  public Tuple9(@NotNull T1 e1, @NotNull T2 e2, @NotNull T3 e3, @NotNull T4 e4, @NotNull T5 e5, @NotNull T6 e6, @NotNull T7 e7, @NotNull T8 e8, @NotNull T9 e9)
  {
    assert e1 != null;
    elem1 = e1;
    assert e2 != null;
    elem2 = e2;
    assert e3 != null;
    elem3 = e3;
    assert e4 != null;
    elem4 = e4;
    assert e5 != null;
    elem5 = e5;
    assert e6 != null;
    elem6 = e6;
    assert e7 != null;
    elem7 = e7;
    assert e8 != null;
    elem8 = e8;
    assert e9 != null;
    elem9 = e9;
  }

  @NotNull
  @Override
  public T1 _1()  {
    return elem1;
  }

  @NotNull
  @Override
  public T2 _2()  {
    return elem2;
  }

  @NotNull
  @Override
  public T3 _3()  {
    return elem3;
  }

  @NotNull
  @Override
  public T4 _4()  {
    return elem4;
  }

  @NotNull
  @Override
  public T5 _5()  {
    return elem5;
  }

  @NotNull
  @Override
  public T6 _6()  {
    return elem6;
  }

  @NotNull
  @Override
  public T7 _7()  {
    return elem7;
  }

  @NotNull
  @Override
  public T8 _8()  {
    return elem8;
  }

  @NotNull
  @Override
  public T9 _9()  {
    return elem9;
  }

  @NotNull
  @Override
  public Tuple8<T1, T2, T3, T4, T5, T6, T7, T8> _12345678()  {
    return new Tuple8<>(elem1, elem2, elem3, elem4, elem5, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple8<T1, T2, T3, T4, T5, T6, T7, T9> _12345679()  {
    return new Tuple8<>(elem1, elem2, elem3, elem4, elem5, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple8<T1, T2, T3, T4, T5, T6, T8, T9> _12345689()  {
    return new Tuple8<>(elem1, elem2, elem3, elem4, elem5, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple8<T1, T2, T3, T4, T5, T7, T8, T9> _12345789()  {
    return new Tuple8<>(elem1, elem2, elem3, elem4, elem5, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple8<T1, T2, T3, T4, T6, T7, T8, T9> _12346789()  {
    return new Tuple8<>(elem1, elem2, elem3, elem4, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple8<T1, T2, T3, T5, T6, T7, T8, T9> _12356789()  {
    return new Tuple8<>(elem1, elem2, elem3, elem5, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple8<T1, T2, T4, T5, T6, T7, T8, T9> _12456789()  {
    return new Tuple8<>(elem1, elem2, elem4, elem5, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple8<T1, T3, T4, T5, T6, T7, T8, T9> _13456789()  {
    return new Tuple8<>(elem1, elem3, elem4, elem5, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple8<T2, T3, T4, T5, T6, T7, T8, T9> _23456789()  {
    return new Tuple8<>(elem2, elem3, elem4, elem5, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T1, T2, T3, T4, T5, T6, T7> _1234567()  {
    return new Tuple7<>(elem1, elem2, elem3, elem4, elem5, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple7<T1, T2, T3, T4, T5, T6, T8> _1234568()  {
    return new Tuple7<>(elem1, elem2, elem3, elem4, elem5, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple7<T1, T2, T3, T4, T5, T7, T8> _1234578()  {
    return new Tuple7<>(elem1, elem2, elem3, elem4, elem5, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple7<T1, T2, T3, T4, T6, T7, T8> _1234678()  {
    return new Tuple7<>(elem1, elem2, elem3, elem4, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple7<T1, T2, T3, T5, T6, T7, T8> _1235678()  {
    return new Tuple7<>(elem1, elem2, elem3, elem5, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple7<T1, T2, T4, T5, T6, T7, T8> _1245678()  {
    return new Tuple7<>(elem1, elem2, elem4, elem5, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple7<T1, T3, T4, T5, T6, T7, T8> _1345678()  {
    return new Tuple7<>(elem1, elem3, elem4, elem5, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple7<T2, T3, T4, T5, T6, T7, T8> _2345678()  {
    return new Tuple7<>(elem2, elem3, elem4, elem5, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple7<T1, T2, T3, T4, T5, T6, T9> _1234569()  {
    return new Tuple7<>(elem1, elem2, elem3, elem4, elem5, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T1, T2, T3, T4, T5, T7, T9> _1234579()  {
    return new Tuple7<>(elem1, elem2, elem3, elem4, elem5, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T1, T2, T3, T4, T6, T7, T9> _1234679()  {
    return new Tuple7<>(elem1, elem2, elem3, elem4, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T1, T2, T3, T5, T6, T7, T9> _1235679()  {
    return new Tuple7<>(elem1, elem2, elem3, elem5, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T1, T2, T4, T5, T6, T7, T9> _1245679()  {
    return new Tuple7<>(elem1, elem2, elem4, elem5, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T1, T3, T4, T5, T6, T7, T9> _1345679()  {
    return new Tuple7<>(elem1, elem3, elem4, elem5, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T2, T3, T4, T5, T6, T7, T9> _2345679()  {
    return new Tuple7<>(elem2, elem3, elem4, elem5, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T1, T2, T3, T4, T5, T8, T9> _1234589()  {
    return new Tuple7<>(elem1, elem2, elem3, elem4, elem5, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T1, T2, T3, T4, T6, T8, T9> _1234689()  {
    return new Tuple7<>(elem1, elem2, elem3, elem4, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T1, T2, T3, T5, T6, T8, T9> _1235689()  {
    return new Tuple7<>(elem1, elem2, elem3, elem5, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T1, T2, T4, T5, T6, T8, T9> _1245689()  {
    return new Tuple7<>(elem1, elem2, elem4, elem5, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T1, T3, T4, T5, T6, T8, T9> _1345689()  {
    return new Tuple7<>(elem1, elem3, elem4, elem5, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T2, T3, T4, T5, T6, T8, T9> _2345689()  {
    return new Tuple7<>(elem2, elem3, elem4, elem5, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T1, T2, T3, T4, T7, T8, T9> _1234789()  {
    return new Tuple7<>(elem1, elem2, elem3, elem4, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T1, T2, T3, T5, T7, T8, T9> _1235789()  {
    return new Tuple7<>(elem1, elem2, elem3, elem5, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T1, T2, T4, T5, T7, T8, T9> _1245789()  {
    return new Tuple7<>(elem1, elem2, elem4, elem5, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T1, T3, T4, T5, T7, T8, T9> _1345789()  {
    return new Tuple7<>(elem1, elem3, elem4, elem5, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T2, T3, T4, T5, T7, T8, T9> _2345789()  {
    return new Tuple7<>(elem2, elem3, elem4, elem5, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T1, T2, T3, T6, T7, T8, T9> _1236789()  {
    return new Tuple7<>(elem1, elem2, elem3, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T1, T2, T4, T6, T7, T8, T9> _1246789()  {
    return new Tuple7<>(elem1, elem2, elem4, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T1, T3, T4, T6, T7, T8, T9> _1346789()  {
    return new Tuple7<>(elem1, elem3, elem4, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T2, T3, T4, T6, T7, T8, T9> _2346789()  {
    return new Tuple7<>(elem2, elem3, elem4, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T1, T2, T5, T6, T7, T8, T9> _1256789()  {
    return new Tuple7<>(elem1, elem2, elem5, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T1, T3, T5, T6, T7, T8, T9> _1356789()  {
    return new Tuple7<>(elem1, elem3, elem5, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T2, T3, T5, T6, T7, T8, T9> _2356789()  {
    return new Tuple7<>(elem2, elem3, elem5, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T1, T4, T5, T6, T7, T8, T9> _1456789()  {
    return new Tuple7<>(elem1, elem4, elem5, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T2, T4, T5, T6, T7, T8, T9> _2456789()  {
    return new Tuple7<>(elem2, elem4, elem5, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple7<T3, T4, T5, T6, T7, T8, T9> _3456789()  {
    return new Tuple7<>(elem3, elem4, elem5, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T3, T4, T5, T6> _123456()  {
    return new Tuple6<>(elem1, elem2, elem3, elem4, elem5, elem6);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T3, T4, T5, T7> _123457()  {
    return new Tuple6<>(elem1, elem2, elem3, elem4, elem5, elem7);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T3, T4, T6, T7> _123467()  {
    return new Tuple6<>(elem1, elem2, elem3, elem4, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T3, T5, T6, T7> _123567()  {
    return new Tuple6<>(elem1, elem2, elem3, elem5, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T4, T5, T6, T7> _124567()  {
    return new Tuple6<>(elem1, elem2, elem4, elem5, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple6<T1, T3, T4, T5, T6, T7> _134567()  {
    return new Tuple6<>(elem1, elem3, elem4, elem5, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple6<T2, T3, T4, T5, T6, T7> _234567()  {
    return new Tuple6<>(elem2, elem3, elem4, elem5, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T3, T4, T5, T8> _123458()  {
    return new Tuple6<>(elem1, elem2, elem3, elem4, elem5, elem8);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T3, T4, T6, T8> _123468()  {
    return new Tuple6<>(elem1, elem2, elem3, elem4, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T3, T5, T6, T8> _123568()  {
    return new Tuple6<>(elem1, elem2, elem3, elem5, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T4, T5, T6, T8> _124568()  {
    return new Tuple6<>(elem1, elem2, elem4, elem5, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple6<T1, T3, T4, T5, T6, T8> _134568()  {
    return new Tuple6<>(elem1, elem3, elem4, elem5, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple6<T2, T3, T4, T5, T6, T8> _234568()  {
    return new Tuple6<>(elem2, elem3, elem4, elem5, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T3, T4, T7, T8> _123478()  {
    return new Tuple6<>(elem1, elem2, elem3, elem4, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T3, T5, T7, T8> _123578()  {
    return new Tuple6<>(elem1, elem2, elem3, elem5, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T4, T5, T7, T8> _124578()  {
    return new Tuple6<>(elem1, elem2, elem4, elem5, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple6<T1, T3, T4, T5, T7, T8> _134578()  {
    return new Tuple6<>(elem1, elem3, elem4, elem5, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple6<T2, T3, T4, T5, T7, T8> _234578()  {
    return new Tuple6<>(elem2, elem3, elem4, elem5, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T3, T6, T7, T8> _123678()  {
    return new Tuple6<>(elem1, elem2, elem3, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T4, T6, T7, T8> _124678()  {
    return new Tuple6<>(elem1, elem2, elem4, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple6<T1, T3, T4, T6, T7, T8> _134678()  {
    return new Tuple6<>(elem1, elem3, elem4, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple6<T2, T3, T4, T6, T7, T8> _234678()  {
    return new Tuple6<>(elem2, elem3, elem4, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T5, T6, T7, T8> _125678()  {
    return new Tuple6<>(elem1, elem2, elem5, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple6<T1, T3, T5, T6, T7, T8> _135678()  {
    return new Tuple6<>(elem1, elem3, elem5, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple6<T2, T3, T5, T6, T7, T8> _235678()  {
    return new Tuple6<>(elem2, elem3, elem5, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple6<T1, T4, T5, T6, T7, T8> _145678()  {
    return new Tuple6<>(elem1, elem4, elem5, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple6<T2, T4, T5, T6, T7, T8> _245678()  {
    return new Tuple6<>(elem2, elem4, elem5, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple6<T3, T4, T5, T6, T7, T8> _345678()  {
    return new Tuple6<>(elem3, elem4, elem5, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T3, T4, T5, T9> _123459()  {
    return new Tuple6<>(elem1, elem2, elem3, elem4, elem5, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T3, T4, T6, T9> _123469()  {
    return new Tuple6<>(elem1, elem2, elem3, elem4, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T3, T5, T6, T9> _123569()  {
    return new Tuple6<>(elem1, elem2, elem3, elem5, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T4, T5, T6, T9> _124569()  {
    return new Tuple6<>(elem1, elem2, elem4, elem5, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T3, T4, T5, T6, T9> _134569()  {
    return new Tuple6<>(elem1, elem3, elem4, elem5, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T2, T3, T4, T5, T6, T9> _234569()  {
    return new Tuple6<>(elem2, elem3, elem4, elem5, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T3, T4, T7, T9> _123479()  {
    return new Tuple6<>(elem1, elem2, elem3, elem4, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T3, T5, T7, T9> _123579()  {
    return new Tuple6<>(elem1, elem2, elem3, elem5, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T4, T5, T7, T9> _124579()  {
    return new Tuple6<>(elem1, elem2, elem4, elem5, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T3, T4, T5, T7, T9> _134579()  {
    return new Tuple6<>(elem1, elem3, elem4, elem5, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T2, T3, T4, T5, T7, T9> _234579()  {
    return new Tuple6<>(elem2, elem3, elem4, elem5, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T3, T6, T7, T9> _123679()  {
    return new Tuple6<>(elem1, elem2, elem3, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T4, T6, T7, T9> _124679()  {
    return new Tuple6<>(elem1, elem2, elem4, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T3, T4, T6, T7, T9> _134679()  {
    return new Tuple6<>(elem1, elem3, elem4, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T2, T3, T4, T6, T7, T9> _234679()  {
    return new Tuple6<>(elem2, elem3, elem4, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T5, T6, T7, T9> _125679()  {
    return new Tuple6<>(elem1, elem2, elem5, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T3, T5, T6, T7, T9> _135679()  {
    return new Tuple6<>(elem1, elem3, elem5, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T2, T3, T5, T6, T7, T9> _235679()  {
    return new Tuple6<>(elem2, elem3, elem5, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T4, T5, T6, T7, T9> _145679()  {
    return new Tuple6<>(elem1, elem4, elem5, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T2, T4, T5, T6, T7, T9> _245679()  {
    return new Tuple6<>(elem2, elem4, elem5, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T3, T4, T5, T6, T7, T9> _345679()  {
    return new Tuple6<>(elem3, elem4, elem5, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T3, T4, T8, T9> _123489()  {
    return new Tuple6<>(elem1, elem2, elem3, elem4, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T3, T5, T8, T9> _123589()  {
    return new Tuple6<>(elem1, elem2, elem3, elem5, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T4, T5, T8, T9> _124589()  {
    return new Tuple6<>(elem1, elem2, elem4, elem5, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T3, T4, T5, T8, T9> _134589()  {
    return new Tuple6<>(elem1, elem3, elem4, elem5, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T2, T3, T4, T5, T8, T9> _234589()  {
    return new Tuple6<>(elem2, elem3, elem4, elem5, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T3, T6, T8, T9> _123689()  {
    return new Tuple6<>(elem1, elem2, elem3, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T4, T6, T8, T9> _124689()  {
    return new Tuple6<>(elem1, elem2, elem4, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T3, T4, T6, T8, T9> _134689()  {
    return new Tuple6<>(elem1, elem3, elem4, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T2, T3, T4, T6, T8, T9> _234689()  {
    return new Tuple6<>(elem2, elem3, elem4, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T5, T6, T8, T9> _125689()  {
    return new Tuple6<>(elem1, elem2, elem5, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T3, T5, T6, T8, T9> _135689()  {
    return new Tuple6<>(elem1, elem3, elem5, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T2, T3, T5, T6, T8, T9> _235689()  {
    return new Tuple6<>(elem2, elem3, elem5, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T4, T5, T6, T8, T9> _145689()  {
    return new Tuple6<>(elem1, elem4, elem5, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T2, T4, T5, T6, T8, T9> _245689()  {
    return new Tuple6<>(elem2, elem4, elem5, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T3, T4, T5, T6, T8, T9> _345689()  {
    return new Tuple6<>(elem3, elem4, elem5, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T3, T7, T8, T9> _123789()  {
    return new Tuple6<>(elem1, elem2, elem3, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T4, T7, T8, T9> _124789()  {
    return new Tuple6<>(elem1, elem2, elem4, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T3, T4, T7, T8, T9> _134789()  {
    return new Tuple6<>(elem1, elem3, elem4, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T2, T3, T4, T7, T8, T9> _234789()  {
    return new Tuple6<>(elem2, elem3, elem4, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T5, T7, T8, T9> _125789()  {
    return new Tuple6<>(elem1, elem2, elem5, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T3, T5, T7, T8, T9> _135789()  {
    return new Tuple6<>(elem1, elem3, elem5, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T2, T3, T5, T7, T8, T9> _235789()  {
    return new Tuple6<>(elem2, elem3, elem5, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T4, T5, T7, T8, T9> _145789()  {
    return new Tuple6<>(elem1, elem4, elem5, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T2, T4, T5, T7, T8, T9> _245789()  {
    return new Tuple6<>(elem2, elem4, elem5, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T3, T4, T5, T7, T8, T9> _345789()  {
    return new Tuple6<>(elem3, elem4, elem5, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T2, T6, T7, T8, T9> _126789()  {
    return new Tuple6<>(elem1, elem2, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T3, T6, T7, T8, T9> _136789()  {
    return new Tuple6<>(elem1, elem3, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T2, T3, T6, T7, T8, T9> _236789()  {
    return new Tuple6<>(elem2, elem3, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T4, T6, T7, T8, T9> _146789()  {
    return new Tuple6<>(elem1, elem4, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T2, T4, T6, T7, T8, T9> _246789()  {
    return new Tuple6<>(elem2, elem4, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T3, T4, T6, T7, T8, T9> _346789()  {
    return new Tuple6<>(elem3, elem4, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T1, T5, T6, T7, T8, T9> _156789()  {
    return new Tuple6<>(elem1, elem5, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T2, T5, T6, T7, T8, T9> _256789()  {
    return new Tuple6<>(elem2, elem5, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T3, T5, T6, T7, T8, T9> _356789()  {
    return new Tuple6<>(elem3, elem5, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple6<T4, T5, T6, T7, T8, T9> _456789()  {
    return new Tuple6<>(elem4, elem5, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T3, T4, T5> _12345()  {
    return new Tuple5<>(elem1, elem2, elem3, elem4, elem5);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T3, T4, T6> _12346()  {
    return new Tuple5<>(elem1, elem2, elem3, elem4, elem6);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T3, T5, T6> _12356()  {
    return new Tuple5<>(elem1, elem2, elem3, elem5, elem6);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T4, T5, T6> _12456()  {
    return new Tuple5<>(elem1, elem2, elem4, elem5, elem6);
  }

  @NotNull
  @Override
  public Tuple5<T1, T3, T4, T5, T6> _13456()  {
    return new Tuple5<>(elem1, elem3, elem4, elem5, elem6);
  }

  @NotNull
  @Override
  public Tuple5<T2, T3, T4, T5, T6> _23456()  {
    return new Tuple5<>(elem2, elem3, elem4, elem5, elem6);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T3, T4, T7> _12347()  {
    return new Tuple5<>(elem1, elem2, elem3, elem4, elem7);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T3, T5, T7> _12357()  {
    return new Tuple5<>(elem1, elem2, elem3, elem5, elem7);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T4, T5, T7> _12457()  {
    return new Tuple5<>(elem1, elem2, elem4, elem5, elem7);
  }

  @NotNull
  @Override
  public Tuple5<T1, T3, T4, T5, T7> _13457()  {
    return new Tuple5<>(elem1, elem3, elem4, elem5, elem7);
  }

  @NotNull
  @Override
  public Tuple5<T2, T3, T4, T5, T7> _23457()  {
    return new Tuple5<>(elem2, elem3, elem4, elem5, elem7);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T3, T6, T7> _12367()  {
    return new Tuple5<>(elem1, elem2, elem3, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T4, T6, T7> _12467()  {
    return new Tuple5<>(elem1, elem2, elem4, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple5<T1, T3, T4, T6, T7> _13467()  {
    return new Tuple5<>(elem1, elem3, elem4, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple5<T2, T3, T4, T6, T7> _23467()  {
    return new Tuple5<>(elem2, elem3, elem4, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T5, T6, T7> _12567()  {
    return new Tuple5<>(elem1, elem2, elem5, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple5<T1, T3, T5, T6, T7> _13567()  {
    return new Tuple5<>(elem1, elem3, elem5, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple5<T2, T3, T5, T6, T7> _23567()  {
    return new Tuple5<>(elem2, elem3, elem5, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple5<T1, T4, T5, T6, T7> _14567()  {
    return new Tuple5<>(elem1, elem4, elem5, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple5<T2, T4, T5, T6, T7> _24567()  {
    return new Tuple5<>(elem2, elem4, elem5, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple5<T3, T4, T5, T6, T7> _34567()  {
    return new Tuple5<>(elem3, elem4, elem5, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T3, T4, T8> _12348()  {
    return new Tuple5<>(elem1, elem2, elem3, elem4, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T3, T5, T8> _12358()  {
    return new Tuple5<>(elem1, elem2, elem3, elem5, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T4, T5, T8> _12458()  {
    return new Tuple5<>(elem1, elem2, elem4, elem5, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T1, T3, T4, T5, T8> _13458()  {
    return new Tuple5<>(elem1, elem3, elem4, elem5, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T2, T3, T4, T5, T8> _23458()  {
    return new Tuple5<>(elem2, elem3, elem4, elem5, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T3, T6, T8> _12368()  {
    return new Tuple5<>(elem1, elem2, elem3, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T4, T6, T8> _12468()  {
    return new Tuple5<>(elem1, elem2, elem4, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T1, T3, T4, T6, T8> _13468()  {
    return new Tuple5<>(elem1, elem3, elem4, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T2, T3, T4, T6, T8> _23468()  {
    return new Tuple5<>(elem2, elem3, elem4, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T5, T6, T8> _12568()  {
    return new Tuple5<>(elem1, elem2, elem5, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T1, T3, T5, T6, T8> _13568()  {
    return new Tuple5<>(elem1, elem3, elem5, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T2, T3, T5, T6, T8> _23568()  {
    return new Tuple5<>(elem2, elem3, elem5, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T1, T4, T5, T6, T8> _14568()  {
    return new Tuple5<>(elem1, elem4, elem5, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T2, T4, T5, T6, T8> _24568()  {
    return new Tuple5<>(elem2, elem4, elem5, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T3, T4, T5, T6, T8> _34568()  {
    return new Tuple5<>(elem3, elem4, elem5, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T3, T7, T8> _12378()  {
    return new Tuple5<>(elem1, elem2, elem3, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T4, T7, T8> _12478()  {
    return new Tuple5<>(elem1, elem2, elem4, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T1, T3, T4, T7, T8> _13478()  {
    return new Tuple5<>(elem1, elem3, elem4, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T2, T3, T4, T7, T8> _23478()  {
    return new Tuple5<>(elem2, elem3, elem4, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T5, T7, T8> _12578()  {
    return new Tuple5<>(elem1, elem2, elem5, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T1, T3, T5, T7, T8> _13578()  {
    return new Tuple5<>(elem1, elem3, elem5, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T2, T3, T5, T7, T8> _23578()  {
    return new Tuple5<>(elem2, elem3, elem5, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T1, T4, T5, T7, T8> _14578()  {
    return new Tuple5<>(elem1, elem4, elem5, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T2, T4, T5, T7, T8> _24578()  {
    return new Tuple5<>(elem2, elem4, elem5, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T3, T4, T5, T7, T8> _34578()  {
    return new Tuple5<>(elem3, elem4, elem5, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T6, T7, T8> _12678()  {
    return new Tuple5<>(elem1, elem2, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T1, T3, T6, T7, T8> _13678()  {
    return new Tuple5<>(elem1, elem3, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T2, T3, T6, T7, T8> _23678()  {
    return new Tuple5<>(elem2, elem3, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T1, T4, T6, T7, T8> _14678()  {
    return new Tuple5<>(elem1, elem4, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T2, T4, T6, T7, T8> _24678()  {
    return new Tuple5<>(elem2, elem4, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T3, T4, T6, T7, T8> _34678()  {
    return new Tuple5<>(elem3, elem4, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T1, T5, T6, T7, T8> _15678()  {
    return new Tuple5<>(elem1, elem5, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T2, T5, T6, T7, T8> _25678()  {
    return new Tuple5<>(elem2, elem5, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T3, T5, T6, T7, T8> _35678()  {
    return new Tuple5<>(elem3, elem5, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T4, T5, T6, T7, T8> _45678()  {
    return new Tuple5<>(elem4, elem5, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T3, T4, T9> _12349()  {
    return new Tuple5<>(elem1, elem2, elem3, elem4, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T3, T5, T9> _12359()  {
    return new Tuple5<>(elem1, elem2, elem3, elem5, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T4, T5, T9> _12459()  {
    return new Tuple5<>(elem1, elem2, elem4, elem5, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T3, T4, T5, T9> _13459()  {
    return new Tuple5<>(elem1, elem3, elem4, elem5, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T2, T3, T4, T5, T9> _23459()  {
    return new Tuple5<>(elem2, elem3, elem4, elem5, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T3, T6, T9> _12369()  {
    return new Tuple5<>(elem1, elem2, elem3, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T4, T6, T9> _12469()  {
    return new Tuple5<>(elem1, elem2, elem4, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T3, T4, T6, T9> _13469()  {
    return new Tuple5<>(elem1, elem3, elem4, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T2, T3, T4, T6, T9> _23469()  {
    return new Tuple5<>(elem2, elem3, elem4, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T5, T6, T9> _12569()  {
    return new Tuple5<>(elem1, elem2, elem5, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T3, T5, T6, T9> _13569()  {
    return new Tuple5<>(elem1, elem3, elem5, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T2, T3, T5, T6, T9> _23569()  {
    return new Tuple5<>(elem2, elem3, elem5, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T4, T5, T6, T9> _14569()  {
    return new Tuple5<>(elem1, elem4, elem5, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T2, T4, T5, T6, T9> _24569()  {
    return new Tuple5<>(elem2, elem4, elem5, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T3, T4, T5, T6, T9> _34569()  {
    return new Tuple5<>(elem3, elem4, elem5, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T3, T7, T9> _12379()  {
    return new Tuple5<>(elem1, elem2, elem3, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T4, T7, T9> _12479()  {
    return new Tuple5<>(elem1, elem2, elem4, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T3, T4, T7, T9> _13479()  {
    return new Tuple5<>(elem1, elem3, elem4, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T2, T3, T4, T7, T9> _23479()  {
    return new Tuple5<>(elem2, elem3, elem4, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T5, T7, T9> _12579()  {
    return new Tuple5<>(elem1, elem2, elem5, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T3, T5, T7, T9> _13579()  {
    return new Tuple5<>(elem1, elem3, elem5, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T2, T3, T5, T7, T9> _23579()  {
    return new Tuple5<>(elem2, elem3, elem5, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T4, T5, T7, T9> _14579()  {
    return new Tuple5<>(elem1, elem4, elem5, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T2, T4, T5, T7, T9> _24579()  {
    return new Tuple5<>(elem2, elem4, elem5, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T3, T4, T5, T7, T9> _34579()  {
    return new Tuple5<>(elem3, elem4, elem5, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T6, T7, T9> _12679()  {
    return new Tuple5<>(elem1, elem2, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T3, T6, T7, T9> _13679()  {
    return new Tuple5<>(elem1, elem3, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T2, T3, T6, T7, T9> _23679()  {
    return new Tuple5<>(elem2, elem3, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T4, T6, T7, T9> _14679()  {
    return new Tuple5<>(elem1, elem4, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T2, T4, T6, T7, T9> _24679()  {
    return new Tuple5<>(elem2, elem4, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T3, T4, T6, T7, T9> _34679()  {
    return new Tuple5<>(elem3, elem4, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T5, T6, T7, T9> _15679()  {
    return new Tuple5<>(elem1, elem5, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T2, T5, T6, T7, T9> _25679()  {
    return new Tuple5<>(elem2, elem5, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T3, T5, T6, T7, T9> _35679()  {
    return new Tuple5<>(elem3, elem5, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T4, T5, T6, T7, T9> _45679()  {
    return new Tuple5<>(elem4, elem5, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T3, T8, T9> _12389()  {
    return new Tuple5<>(elem1, elem2, elem3, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T4, T8, T9> _12489()  {
    return new Tuple5<>(elem1, elem2, elem4, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T3, T4, T8, T9> _13489()  {
    return new Tuple5<>(elem1, elem3, elem4, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T2, T3, T4, T8, T9> _23489()  {
    return new Tuple5<>(elem2, elem3, elem4, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T5, T8, T9> _12589()  {
    return new Tuple5<>(elem1, elem2, elem5, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T3, T5, T8, T9> _13589()  {
    return new Tuple5<>(elem1, elem3, elem5, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T2, T3, T5, T8, T9> _23589()  {
    return new Tuple5<>(elem2, elem3, elem5, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T4, T5, T8, T9> _14589()  {
    return new Tuple5<>(elem1, elem4, elem5, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T2, T4, T5, T8, T9> _24589()  {
    return new Tuple5<>(elem2, elem4, elem5, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T3, T4, T5, T8, T9> _34589()  {
    return new Tuple5<>(elem3, elem4, elem5, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T6, T8, T9> _12689()  {
    return new Tuple5<>(elem1, elem2, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T3, T6, T8, T9> _13689()  {
    return new Tuple5<>(elem1, elem3, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T2, T3, T6, T8, T9> _23689()  {
    return new Tuple5<>(elem2, elem3, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T4, T6, T8, T9> _14689()  {
    return new Tuple5<>(elem1, elem4, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T2, T4, T6, T8, T9> _24689()  {
    return new Tuple5<>(elem2, elem4, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T3, T4, T6, T8, T9> _34689()  {
    return new Tuple5<>(elem3, elem4, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T5, T6, T8, T9> _15689()  {
    return new Tuple5<>(elem1, elem5, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T2, T5, T6, T8, T9> _25689()  {
    return new Tuple5<>(elem2, elem5, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T3, T5, T6, T8, T9> _35689()  {
    return new Tuple5<>(elem3, elem5, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T4, T5, T6, T8, T9> _45689()  {
    return new Tuple5<>(elem4, elem5, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T2, T7, T8, T9> _12789()  {
    return new Tuple5<>(elem1, elem2, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T3, T7, T8, T9> _13789()  {
    return new Tuple5<>(elem1, elem3, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T2, T3, T7, T8, T9> _23789()  {
    return new Tuple5<>(elem2, elem3, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T4, T7, T8, T9> _14789()  {
    return new Tuple5<>(elem1, elem4, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T2, T4, T7, T8, T9> _24789()  {
    return new Tuple5<>(elem2, elem4, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T3, T4, T7, T8, T9> _34789()  {
    return new Tuple5<>(elem3, elem4, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T5, T7, T8, T9> _15789()  {
    return new Tuple5<>(elem1, elem5, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T2, T5, T7, T8, T9> _25789()  {
    return new Tuple5<>(elem2, elem5, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T3, T5, T7, T8, T9> _35789()  {
    return new Tuple5<>(elem3, elem5, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T4, T5, T7, T8, T9> _45789()  {
    return new Tuple5<>(elem4, elem5, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T1, T6, T7, T8, T9> _16789()  {
    return new Tuple5<>(elem1, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T2, T6, T7, T8, T9> _26789()  {
    return new Tuple5<>(elem2, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T3, T6, T7, T8, T9> _36789()  {
    return new Tuple5<>(elem3, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T4, T6, T7, T8, T9> _46789()  {
    return new Tuple5<>(elem4, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple5<T5, T6, T7, T8, T9> _56789()  {
    return new Tuple5<>(elem5, elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T1, T2, T3, T4> _1234()  {
    return new Tuple4<>(elem1, elem2, elem3, elem4);
  }

  @NotNull
  @Override
  public Tuple4<T1, T2, T3, T5> _1235()  {
    return new Tuple4<>(elem1, elem2, elem3, elem5);
  }

  @NotNull
  @Override
  public Tuple4<T1, T2, T4, T5> _1245()  {
    return new Tuple4<>(elem1, elem2, elem4, elem5);
  }

  @NotNull
  @Override
  public Tuple4<T1, T3, T4, T5> _1345()  {
    return new Tuple4<>(elem1, elem3, elem4, elem5);
  }

  @NotNull
  @Override
  public Tuple4<T2, T3, T4, T5> _2345()  {
    return new Tuple4<>(elem2, elem3, elem4, elem5);
  }

  @NotNull
  @Override
  public Tuple4<T1, T2, T3, T6> _1236()  {
    return new Tuple4<>(elem1, elem2, elem3, elem6);
  }

  @NotNull
  @Override
  public Tuple4<T1, T2, T4, T6> _1246()  {
    return new Tuple4<>(elem1, elem2, elem4, elem6);
  }

  @NotNull
  @Override
  public Tuple4<T1, T3, T4, T6> _1346()  {
    return new Tuple4<>(elem1, elem3, elem4, elem6);
  }

  @NotNull
  @Override
  public Tuple4<T2, T3, T4, T6> _2346()  {
    return new Tuple4<>(elem2, elem3, elem4, elem6);
  }

  @NotNull
  @Override
  public Tuple4<T1, T2, T5, T6> _1256()  {
    return new Tuple4<>(elem1, elem2, elem5, elem6);
  }

  @NotNull
  @Override
  public Tuple4<T1, T3, T5, T6> _1356()  {
    return new Tuple4<>(elem1, elem3, elem5, elem6);
  }

  @NotNull
  @Override
  public Tuple4<T2, T3, T5, T6> _2356()  {
    return new Tuple4<>(elem2, elem3, elem5, elem6);
  }

  @NotNull
  @Override
  public Tuple4<T1, T4, T5, T6> _1456()  {
    return new Tuple4<>(elem1, elem4, elem5, elem6);
  }

  @NotNull
  @Override
  public Tuple4<T2, T4, T5, T6> _2456()  {
    return new Tuple4<>(elem2, elem4, elem5, elem6);
  }

  @NotNull
  @Override
  public Tuple4<T3, T4, T5, T6> _3456()  {
    return new Tuple4<>(elem3, elem4, elem5, elem6);
  }

  @NotNull
  @Override
  public Tuple4<T1, T2, T3, T7> _1237()  {
    return new Tuple4<>(elem1, elem2, elem3, elem7);
  }

  @NotNull
  @Override
  public Tuple4<T1, T2, T4, T7> _1247()  {
    return new Tuple4<>(elem1, elem2, elem4, elem7);
  }

  @NotNull
  @Override
  public Tuple4<T1, T3, T4, T7> _1347()  {
    return new Tuple4<>(elem1, elem3, elem4, elem7);
  }

  @NotNull
  @Override
  public Tuple4<T2, T3, T4, T7> _2347()  {
    return new Tuple4<>(elem2, elem3, elem4, elem7);
  }

  @NotNull
  @Override
  public Tuple4<T1, T2, T5, T7> _1257()  {
    return new Tuple4<>(elem1, elem2, elem5, elem7);
  }

  @NotNull
  @Override
  public Tuple4<T1, T3, T5, T7> _1357()  {
    return new Tuple4<>(elem1, elem3, elem5, elem7);
  }

  @NotNull
  @Override
  public Tuple4<T2, T3, T5, T7> _2357()  {
    return new Tuple4<>(elem2, elem3, elem5, elem7);
  }

  @NotNull
  @Override
  public Tuple4<T1, T4, T5, T7> _1457()  {
    return new Tuple4<>(elem1, elem4, elem5, elem7);
  }

  @NotNull
  @Override
  public Tuple4<T2, T4, T5, T7> _2457()  {
    return new Tuple4<>(elem2, elem4, elem5, elem7);
  }

  @NotNull
  @Override
  public Tuple4<T3, T4, T5, T7> _3457()  {
    return new Tuple4<>(elem3, elem4, elem5, elem7);
  }

  @NotNull
  @Override
  public Tuple4<T1, T2, T6, T7> _1267()  {
    return new Tuple4<>(elem1, elem2, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple4<T1, T3, T6, T7> _1367()  {
    return new Tuple4<>(elem1, elem3, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple4<T2, T3, T6, T7> _2367()  {
    return new Tuple4<>(elem2, elem3, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple4<T1, T4, T6, T7> _1467()  {
    return new Tuple4<>(elem1, elem4, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple4<T2, T4, T6, T7> _2467()  {
    return new Tuple4<>(elem2, elem4, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple4<T3, T4, T6, T7> _3467()  {
    return new Tuple4<>(elem3, elem4, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple4<T1, T5, T6, T7> _1567()  {
    return new Tuple4<>(elem1, elem5, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple4<T2, T5, T6, T7> _2567()  {
    return new Tuple4<>(elem2, elem5, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple4<T3, T5, T6, T7> _3567()  {
    return new Tuple4<>(elem3, elem5, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple4<T4, T5, T6, T7> _4567()  {
    return new Tuple4<>(elem4, elem5, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple4<T1, T2, T3, T8> _1238()  {
    return new Tuple4<>(elem1, elem2, elem3, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T1, T2, T4, T8> _1248()  {
    return new Tuple4<>(elem1, elem2, elem4, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T1, T3, T4, T8> _1348()  {
    return new Tuple4<>(elem1, elem3, elem4, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T2, T3, T4, T8> _2348()  {
    return new Tuple4<>(elem2, elem3, elem4, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T1, T2, T5, T8> _1258()  {
    return new Tuple4<>(elem1, elem2, elem5, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T1, T3, T5, T8> _1358()  {
    return new Tuple4<>(elem1, elem3, elem5, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T2, T3, T5, T8> _2358()  {
    return new Tuple4<>(elem2, elem3, elem5, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T1, T4, T5, T8> _1458()  {
    return new Tuple4<>(elem1, elem4, elem5, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T2, T4, T5, T8> _2458()  {
    return new Tuple4<>(elem2, elem4, elem5, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T3, T4, T5, T8> _3458()  {
    return new Tuple4<>(elem3, elem4, elem5, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T1, T2, T6, T8> _1268()  {
    return new Tuple4<>(elem1, elem2, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T1, T3, T6, T8> _1368()  {
    return new Tuple4<>(elem1, elem3, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T2, T3, T6, T8> _2368()  {
    return new Tuple4<>(elem2, elem3, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T1, T4, T6, T8> _1468()  {
    return new Tuple4<>(elem1, elem4, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T2, T4, T6, T8> _2468()  {
    return new Tuple4<>(elem2, elem4, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T3, T4, T6, T8> _3468()  {
    return new Tuple4<>(elem3, elem4, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T1, T5, T6, T8> _1568()  {
    return new Tuple4<>(elem1, elem5, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T2, T5, T6, T8> _2568()  {
    return new Tuple4<>(elem2, elem5, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T3, T5, T6, T8> _3568()  {
    return new Tuple4<>(elem3, elem5, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T4, T5, T6, T8> _4568()  {
    return new Tuple4<>(elem4, elem5, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T1, T2, T7, T8> _1278()  {
    return new Tuple4<>(elem1, elem2, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T1, T3, T7, T8> _1378()  {
    return new Tuple4<>(elem1, elem3, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T2, T3, T7, T8> _2378()  {
    return new Tuple4<>(elem2, elem3, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T1, T4, T7, T8> _1478()  {
    return new Tuple4<>(elem1, elem4, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T2, T4, T7, T8> _2478()  {
    return new Tuple4<>(elem2, elem4, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T3, T4, T7, T8> _3478()  {
    return new Tuple4<>(elem3, elem4, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T1, T5, T7, T8> _1578()  {
    return new Tuple4<>(elem1, elem5, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T2, T5, T7, T8> _2578()  {
    return new Tuple4<>(elem2, elem5, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T3, T5, T7, T8> _3578()  {
    return new Tuple4<>(elem3, elem5, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T4, T5, T7, T8> _4578()  {
    return new Tuple4<>(elem4, elem5, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T1, T6, T7, T8> _1678()  {
    return new Tuple4<>(elem1, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T2, T6, T7, T8> _2678()  {
    return new Tuple4<>(elem2, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T3, T6, T7, T8> _3678()  {
    return new Tuple4<>(elem3, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T4, T6, T7, T8> _4678()  {
    return new Tuple4<>(elem4, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T5, T6, T7, T8> _5678()  {
    return new Tuple4<>(elem5, elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple4<T1, T2, T3, T9> _1239()  {
    return new Tuple4<>(elem1, elem2, elem3, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T1, T2, T4, T9> _1249()  {
    return new Tuple4<>(elem1, elem2, elem4, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T1, T3, T4, T9> _1349()  {
    return new Tuple4<>(elem1, elem3, elem4, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T2, T3, T4, T9> _2349()  {
    return new Tuple4<>(elem2, elem3, elem4, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T1, T2, T5, T9> _1259()  {
    return new Tuple4<>(elem1, elem2, elem5, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T1, T3, T5, T9> _1359()  {
    return new Tuple4<>(elem1, elem3, elem5, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T2, T3, T5, T9> _2359()  {
    return new Tuple4<>(elem2, elem3, elem5, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T1, T4, T5, T9> _1459()  {
    return new Tuple4<>(elem1, elem4, elem5, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T2, T4, T5, T9> _2459()  {
    return new Tuple4<>(elem2, elem4, elem5, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T3, T4, T5, T9> _3459()  {
    return new Tuple4<>(elem3, elem4, elem5, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T1, T2, T6, T9> _1269()  {
    return new Tuple4<>(elem1, elem2, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T1, T3, T6, T9> _1369()  {
    return new Tuple4<>(elem1, elem3, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T2, T3, T6, T9> _2369()  {
    return new Tuple4<>(elem2, elem3, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T1, T4, T6, T9> _1469()  {
    return new Tuple4<>(elem1, elem4, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T2, T4, T6, T9> _2469()  {
    return new Tuple4<>(elem2, elem4, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T3, T4, T6, T9> _3469()  {
    return new Tuple4<>(elem3, elem4, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T1, T5, T6, T9> _1569()  {
    return new Tuple4<>(elem1, elem5, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T2, T5, T6, T9> _2569()  {
    return new Tuple4<>(elem2, elem5, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T3, T5, T6, T9> _3569()  {
    return new Tuple4<>(elem3, elem5, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T4, T5, T6, T9> _4569()  {
    return new Tuple4<>(elem4, elem5, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T1, T2, T7, T9> _1279()  {
    return new Tuple4<>(elem1, elem2, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T1, T3, T7, T9> _1379()  {
    return new Tuple4<>(elem1, elem3, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T2, T3, T7, T9> _2379()  {
    return new Tuple4<>(elem2, elem3, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T1, T4, T7, T9> _1479()  {
    return new Tuple4<>(elem1, elem4, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T2, T4, T7, T9> _2479()  {
    return new Tuple4<>(elem2, elem4, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T3, T4, T7, T9> _3479()  {
    return new Tuple4<>(elem3, elem4, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T1, T5, T7, T9> _1579()  {
    return new Tuple4<>(elem1, elem5, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T2, T5, T7, T9> _2579()  {
    return new Tuple4<>(elem2, elem5, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T3, T5, T7, T9> _3579()  {
    return new Tuple4<>(elem3, elem5, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T4, T5, T7, T9> _4579()  {
    return new Tuple4<>(elem4, elem5, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T1, T6, T7, T9> _1679()  {
    return new Tuple4<>(elem1, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T2, T6, T7, T9> _2679()  {
    return new Tuple4<>(elem2, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T3, T6, T7, T9> _3679()  {
    return new Tuple4<>(elem3, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T4, T6, T7, T9> _4679()  {
    return new Tuple4<>(elem4, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T5, T6, T7, T9> _5679()  {
    return new Tuple4<>(elem5, elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T1, T2, T8, T9> _1289()  {
    return new Tuple4<>(elem1, elem2, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T1, T3, T8, T9> _1389()  {
    return new Tuple4<>(elem1, elem3, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T2, T3, T8, T9> _2389()  {
    return new Tuple4<>(elem2, elem3, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T1, T4, T8, T9> _1489()  {
    return new Tuple4<>(elem1, elem4, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T2, T4, T8, T9> _2489()  {
    return new Tuple4<>(elem2, elem4, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T3, T4, T8, T9> _3489()  {
    return new Tuple4<>(elem3, elem4, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T1, T5, T8, T9> _1589()  {
    return new Tuple4<>(elem1, elem5, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T2, T5, T8, T9> _2589()  {
    return new Tuple4<>(elem2, elem5, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T3, T5, T8, T9> _3589()  {
    return new Tuple4<>(elem3, elem5, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T4, T5, T8, T9> _4589()  {
    return new Tuple4<>(elem4, elem5, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T1, T6, T8, T9> _1689()  {
    return new Tuple4<>(elem1, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T2, T6, T8, T9> _2689()  {
    return new Tuple4<>(elem2, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T3, T6, T8, T9> _3689()  {
    return new Tuple4<>(elem3, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T4, T6, T8, T9> _4689()  {
    return new Tuple4<>(elem4, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T5, T6, T8, T9> _5689()  {
    return new Tuple4<>(elem5, elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T1, T7, T8, T9> _1789()  {
    return new Tuple4<>(elem1, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T2, T7, T8, T9> _2789()  {
    return new Tuple4<>(elem2, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T3, T7, T8, T9> _3789()  {
    return new Tuple4<>(elem3, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T4, T7, T8, T9> _4789()  {
    return new Tuple4<>(elem4, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T5, T7, T8, T9> _5789()  {
    return new Tuple4<>(elem5, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple4<T6, T7, T8, T9> _6789()  {
    return new Tuple4<>(elem6, elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T1, T2, T3> _123()  {
    return new Tuple3<>(elem1, elem2, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T1, T3, T2> _132()  {
    return new Tuple3<>(elem1, elem3, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T3, T1, T2> _312()  {
    return new Tuple3<>(elem3, elem1, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T3, T2, T1> _321()  {
    return new Tuple3<>(elem3, elem2, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T2, T3, T1> _231()  {
    return new Tuple3<>(elem2, elem3, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T2, T1, T3> _213()  {
    return new Tuple3<>(elem2, elem1, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T1, T2, T4> _124()  {
    return new Tuple3<>(elem1, elem2, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T1, T4, T2> _142()  {
    return new Tuple3<>(elem1, elem4, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T4, T1, T2> _412()  {
    return new Tuple3<>(elem4, elem1, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T4, T2, T1> _421()  {
    return new Tuple3<>(elem4, elem2, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T2, T4, T1> _241()  {
    return new Tuple3<>(elem2, elem4, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T2, T1, T4> _214()  {
    return new Tuple3<>(elem2, elem1, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T1, T3, T4> _134()  {
    return new Tuple3<>(elem1, elem3, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T1, T4, T3> _143()  {
    return new Tuple3<>(elem1, elem4, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T4, T1, T3> _413()  {
    return new Tuple3<>(elem4, elem1, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T4, T3, T1> _431()  {
    return new Tuple3<>(elem4, elem3, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T3, T4, T1> _341()  {
    return new Tuple3<>(elem3, elem4, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T3, T1, T4> _314()  {
    return new Tuple3<>(elem3, elem1, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T2, T3, T4> _234()  {
    return new Tuple3<>(elem2, elem3, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T2, T4, T3> _243()  {
    return new Tuple3<>(elem2, elem4, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T4, T2, T3> _423()  {
    return new Tuple3<>(elem4, elem2, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T4, T3, T2> _432()  {
    return new Tuple3<>(elem4, elem3, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T3, T4, T2> _342()  {
    return new Tuple3<>(elem3, elem4, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T3, T2, T4> _324()  {
    return new Tuple3<>(elem3, elem2, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T1, T2, T5> _125()  {
    return new Tuple3<>(elem1, elem2, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T1, T5, T2> _152()  {
    return new Tuple3<>(elem1, elem5, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T5, T1, T2> _512()  {
    return new Tuple3<>(elem5, elem1, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T5, T2, T1> _521()  {
    return new Tuple3<>(elem5, elem2, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T2, T5, T1> _251()  {
    return new Tuple3<>(elem2, elem5, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T2, T1, T5> _215()  {
    return new Tuple3<>(elem2, elem1, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T1, T3, T5> _135()  {
    return new Tuple3<>(elem1, elem3, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T1, T5, T3> _153()  {
    return new Tuple3<>(elem1, elem5, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T5, T1, T3> _513()  {
    return new Tuple3<>(elem5, elem1, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T5, T3, T1> _531()  {
    return new Tuple3<>(elem5, elem3, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T3, T5, T1> _351()  {
    return new Tuple3<>(elem3, elem5, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T3, T1, T5> _315()  {
    return new Tuple3<>(elem3, elem1, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T2, T3, T5> _235()  {
    return new Tuple3<>(elem2, elem3, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T2, T5, T3> _253()  {
    return new Tuple3<>(elem2, elem5, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T5, T2, T3> _523()  {
    return new Tuple3<>(elem5, elem2, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T5, T3, T2> _532()  {
    return new Tuple3<>(elem5, elem3, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T3, T5, T2> _352()  {
    return new Tuple3<>(elem3, elem5, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T3, T2, T5> _325()  {
    return new Tuple3<>(elem3, elem2, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T1, T4, T5> _145()  {
    return new Tuple3<>(elem1, elem4, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T1, T5, T4> _154()  {
    return new Tuple3<>(elem1, elem5, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T5, T1, T4> _514()  {
    return new Tuple3<>(elem5, elem1, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T5, T4, T1> _541()  {
    return new Tuple3<>(elem5, elem4, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T4, T5, T1> _451()  {
    return new Tuple3<>(elem4, elem5, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T4, T1, T5> _415()  {
    return new Tuple3<>(elem4, elem1, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T2, T4, T5> _245()  {
    return new Tuple3<>(elem2, elem4, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T2, T5, T4> _254()  {
    return new Tuple3<>(elem2, elem5, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T5, T2, T4> _524()  {
    return new Tuple3<>(elem5, elem2, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T5, T4, T2> _542()  {
    return new Tuple3<>(elem5, elem4, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T4, T5, T2> _452()  {
    return new Tuple3<>(elem4, elem5, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T4, T2, T5> _425()  {
    return new Tuple3<>(elem4, elem2, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T3, T4, T5> _345()  {
    return new Tuple3<>(elem3, elem4, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T3, T5, T4> _354()  {
    return new Tuple3<>(elem3, elem5, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T5, T3, T4> _534()  {
    return new Tuple3<>(elem5, elem3, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T5, T4, T3> _543()  {
    return new Tuple3<>(elem5, elem4, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T4, T5, T3> _453()  {
    return new Tuple3<>(elem4, elem5, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T4, T3, T5> _435()  {
    return new Tuple3<>(elem4, elem3, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T1, T2, T6> _126()  {
    return new Tuple3<>(elem1, elem2, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T1, T6, T2> _162()  {
    return new Tuple3<>(elem1, elem6, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T6, T1, T2> _612()  {
    return new Tuple3<>(elem6, elem1, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T6, T2, T1> _621()  {
    return new Tuple3<>(elem6, elem2, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T2, T6, T1> _261()  {
    return new Tuple3<>(elem2, elem6, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T2, T1, T6> _216()  {
    return new Tuple3<>(elem2, elem1, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T1, T3, T6> _136()  {
    return new Tuple3<>(elem1, elem3, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T1, T6, T3> _163()  {
    return new Tuple3<>(elem1, elem6, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T6, T1, T3> _613()  {
    return new Tuple3<>(elem6, elem1, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T6, T3, T1> _631()  {
    return new Tuple3<>(elem6, elem3, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T3, T6, T1> _361()  {
    return new Tuple3<>(elem3, elem6, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T3, T1, T6> _316()  {
    return new Tuple3<>(elem3, elem1, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T2, T3, T6> _236()  {
    return new Tuple3<>(elem2, elem3, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T2, T6, T3> _263()  {
    return new Tuple3<>(elem2, elem6, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T6, T2, T3> _623()  {
    return new Tuple3<>(elem6, elem2, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T6, T3, T2> _632()  {
    return new Tuple3<>(elem6, elem3, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T3, T6, T2> _362()  {
    return new Tuple3<>(elem3, elem6, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T3, T2, T6> _326()  {
    return new Tuple3<>(elem3, elem2, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T1, T4, T6> _146()  {
    return new Tuple3<>(elem1, elem4, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T1, T6, T4> _164()  {
    return new Tuple3<>(elem1, elem6, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T6, T1, T4> _614()  {
    return new Tuple3<>(elem6, elem1, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T6, T4, T1> _641()  {
    return new Tuple3<>(elem6, elem4, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T4, T6, T1> _461()  {
    return new Tuple3<>(elem4, elem6, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T4, T1, T6> _416()  {
    return new Tuple3<>(elem4, elem1, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T2, T4, T6> _246()  {
    return new Tuple3<>(elem2, elem4, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T2, T6, T4> _264()  {
    return new Tuple3<>(elem2, elem6, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T6, T2, T4> _624()  {
    return new Tuple3<>(elem6, elem2, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T6, T4, T2> _642()  {
    return new Tuple3<>(elem6, elem4, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T4, T6, T2> _462()  {
    return new Tuple3<>(elem4, elem6, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T4, T2, T6> _426()  {
    return new Tuple3<>(elem4, elem2, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T3, T4, T6> _346()  {
    return new Tuple3<>(elem3, elem4, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T3, T6, T4> _364()  {
    return new Tuple3<>(elem3, elem6, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T6, T3, T4> _634()  {
    return new Tuple3<>(elem6, elem3, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T6, T4, T3> _643()  {
    return new Tuple3<>(elem6, elem4, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T4, T6, T3> _463()  {
    return new Tuple3<>(elem4, elem6, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T4, T3, T6> _436()  {
    return new Tuple3<>(elem4, elem3, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T1, T5, T6> _156()  {
    return new Tuple3<>(elem1, elem5, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T1, T6, T5> _165()  {
    return new Tuple3<>(elem1, elem6, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T6, T1, T5> _615()  {
    return new Tuple3<>(elem6, elem1, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T6, T5, T1> _651()  {
    return new Tuple3<>(elem6, elem5, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T5, T6, T1> _561()  {
    return new Tuple3<>(elem5, elem6, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T5, T1, T6> _516()  {
    return new Tuple3<>(elem5, elem1, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T2, T5, T6> _256()  {
    return new Tuple3<>(elem2, elem5, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T2, T6, T5> _265()  {
    return new Tuple3<>(elem2, elem6, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T6, T2, T5> _625()  {
    return new Tuple3<>(elem6, elem2, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T6, T5, T2> _652()  {
    return new Tuple3<>(elem6, elem5, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T5, T6, T2> _562()  {
    return new Tuple3<>(elem5, elem6, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T5, T2, T6> _526()  {
    return new Tuple3<>(elem5, elem2, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T3, T5, T6> _356()  {
    return new Tuple3<>(elem3, elem5, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T3, T6, T5> _365()  {
    return new Tuple3<>(elem3, elem6, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T6, T3, T5> _635()  {
    return new Tuple3<>(elem6, elem3, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T6, T5, T3> _653()  {
    return new Tuple3<>(elem6, elem5, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T5, T6, T3> _563()  {
    return new Tuple3<>(elem5, elem6, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T5, T3, T6> _536()  {
    return new Tuple3<>(elem5, elem3, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T4, T5, T6> _456()  {
    return new Tuple3<>(elem4, elem5, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T4, T6, T5> _465()  {
    return new Tuple3<>(elem4, elem6, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T6, T4, T5> _645()  {
    return new Tuple3<>(elem6, elem4, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T6, T5, T4> _654()  {
    return new Tuple3<>(elem6, elem5, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T5, T6, T4> _564()  {
    return new Tuple3<>(elem5, elem6, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T5, T4, T6> _546()  {
    return new Tuple3<>(elem5, elem4, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T1, T2, T7> _127()  {
    return new Tuple3<>(elem1, elem2, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T1, T7, T2> _172()  {
    return new Tuple3<>(elem1, elem7, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T7, T1, T2> _712()  {
    return new Tuple3<>(elem7, elem1, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T7, T2, T1> _721()  {
    return new Tuple3<>(elem7, elem2, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T2, T7, T1> _271()  {
    return new Tuple3<>(elem2, elem7, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T2, T1, T7> _217()  {
    return new Tuple3<>(elem2, elem1, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T1, T3, T7> _137()  {
    return new Tuple3<>(elem1, elem3, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T1, T7, T3> _173()  {
    return new Tuple3<>(elem1, elem7, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T7, T1, T3> _713()  {
    return new Tuple3<>(elem7, elem1, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T7, T3, T1> _731()  {
    return new Tuple3<>(elem7, elem3, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T3, T7, T1> _371()  {
    return new Tuple3<>(elem3, elem7, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T3, T1, T7> _317()  {
    return new Tuple3<>(elem3, elem1, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T2, T3, T7> _237()  {
    return new Tuple3<>(elem2, elem3, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T2, T7, T3> _273()  {
    return new Tuple3<>(elem2, elem7, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T7, T2, T3> _723()  {
    return new Tuple3<>(elem7, elem2, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T7, T3, T2> _732()  {
    return new Tuple3<>(elem7, elem3, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T3, T7, T2> _372()  {
    return new Tuple3<>(elem3, elem7, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T3, T2, T7> _327()  {
    return new Tuple3<>(elem3, elem2, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T1, T4, T7> _147()  {
    return new Tuple3<>(elem1, elem4, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T1, T7, T4> _174()  {
    return new Tuple3<>(elem1, elem7, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T7, T1, T4> _714()  {
    return new Tuple3<>(elem7, elem1, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T7, T4, T1> _741()  {
    return new Tuple3<>(elem7, elem4, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T4, T7, T1> _471()  {
    return new Tuple3<>(elem4, elem7, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T4, T1, T7> _417()  {
    return new Tuple3<>(elem4, elem1, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T2, T4, T7> _247()  {
    return new Tuple3<>(elem2, elem4, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T2, T7, T4> _274()  {
    return new Tuple3<>(elem2, elem7, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T7, T2, T4> _724()  {
    return new Tuple3<>(elem7, elem2, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T7, T4, T2> _742()  {
    return new Tuple3<>(elem7, elem4, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T4, T7, T2> _472()  {
    return new Tuple3<>(elem4, elem7, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T4, T2, T7> _427()  {
    return new Tuple3<>(elem4, elem2, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T3, T4, T7> _347()  {
    return new Tuple3<>(elem3, elem4, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T3, T7, T4> _374()  {
    return new Tuple3<>(elem3, elem7, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T7, T3, T4> _734()  {
    return new Tuple3<>(elem7, elem3, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T7, T4, T3> _743()  {
    return new Tuple3<>(elem7, elem4, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T4, T7, T3> _473()  {
    return new Tuple3<>(elem4, elem7, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T4, T3, T7> _437()  {
    return new Tuple3<>(elem4, elem3, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T1, T5, T7> _157()  {
    return new Tuple3<>(elem1, elem5, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T1, T7, T5> _175()  {
    return new Tuple3<>(elem1, elem7, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T7, T1, T5> _715()  {
    return new Tuple3<>(elem7, elem1, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T7, T5, T1> _751()  {
    return new Tuple3<>(elem7, elem5, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T5, T7, T1> _571()  {
    return new Tuple3<>(elem5, elem7, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T5, T1, T7> _517()  {
    return new Tuple3<>(elem5, elem1, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T2, T5, T7> _257()  {
    return new Tuple3<>(elem2, elem5, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T2, T7, T5> _275()  {
    return new Tuple3<>(elem2, elem7, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T7, T2, T5> _725()  {
    return new Tuple3<>(elem7, elem2, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T7, T5, T2> _752()  {
    return new Tuple3<>(elem7, elem5, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T5, T7, T2> _572()  {
    return new Tuple3<>(elem5, elem7, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T5, T2, T7> _527()  {
    return new Tuple3<>(elem5, elem2, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T3, T5, T7> _357()  {
    return new Tuple3<>(elem3, elem5, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T3, T7, T5> _375()  {
    return new Tuple3<>(elem3, elem7, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T7, T3, T5> _735()  {
    return new Tuple3<>(elem7, elem3, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T7, T5, T3> _753()  {
    return new Tuple3<>(elem7, elem5, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T5, T7, T3> _573()  {
    return new Tuple3<>(elem5, elem7, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T5, T3, T7> _537()  {
    return new Tuple3<>(elem5, elem3, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T4, T5, T7> _457()  {
    return new Tuple3<>(elem4, elem5, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T4, T7, T5> _475()  {
    return new Tuple3<>(elem4, elem7, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T7, T4, T5> _745()  {
    return new Tuple3<>(elem7, elem4, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T7, T5, T4> _754()  {
    return new Tuple3<>(elem7, elem5, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T5, T7, T4> _574()  {
    return new Tuple3<>(elem5, elem7, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T5, T4, T7> _547()  {
    return new Tuple3<>(elem5, elem4, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T1, T6, T7> _167()  {
    return new Tuple3<>(elem1, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T1, T7, T6> _176()  {
    return new Tuple3<>(elem1, elem7, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T7, T1, T6> _716()  {
    return new Tuple3<>(elem7, elem1, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T7, T6, T1> _761()  {
    return new Tuple3<>(elem7, elem6, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T6, T7, T1> _671()  {
    return new Tuple3<>(elem6, elem7, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T6, T1, T7> _617()  {
    return new Tuple3<>(elem6, elem1, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T2, T6, T7> _267()  {
    return new Tuple3<>(elem2, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T2, T7, T6> _276()  {
    return new Tuple3<>(elem2, elem7, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T7, T2, T6> _726()  {
    return new Tuple3<>(elem7, elem2, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T7, T6, T2> _762()  {
    return new Tuple3<>(elem7, elem6, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T6, T7, T2> _672()  {
    return new Tuple3<>(elem6, elem7, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T6, T2, T7> _627()  {
    return new Tuple3<>(elem6, elem2, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T3, T6, T7> _367()  {
    return new Tuple3<>(elem3, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T3, T7, T6> _376()  {
    return new Tuple3<>(elem3, elem7, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T7, T3, T6> _736()  {
    return new Tuple3<>(elem7, elem3, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T7, T6, T3> _763()  {
    return new Tuple3<>(elem7, elem6, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T6, T7, T3> _673()  {
    return new Tuple3<>(elem6, elem7, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T6, T3, T7> _637()  {
    return new Tuple3<>(elem6, elem3, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T4, T6, T7> _467()  {
    return new Tuple3<>(elem4, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T4, T7, T6> _476()  {
    return new Tuple3<>(elem4, elem7, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T7, T4, T6> _746()  {
    return new Tuple3<>(elem7, elem4, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T7, T6, T4> _764()  {
    return new Tuple3<>(elem7, elem6, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T6, T7, T4> _674()  {
    return new Tuple3<>(elem6, elem7, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T6, T4, T7> _647()  {
    return new Tuple3<>(elem6, elem4, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T5, T6, T7> _567()  {
    return new Tuple3<>(elem5, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T5, T7, T6> _576()  {
    return new Tuple3<>(elem5, elem7, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T7, T5, T6> _756()  {
    return new Tuple3<>(elem7, elem5, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T7, T6, T5> _765()  {
    return new Tuple3<>(elem7, elem6, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T6, T7, T5> _675()  {
    return new Tuple3<>(elem6, elem7, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T6, T5, T7> _657()  {
    return new Tuple3<>(elem6, elem5, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T1, T2, T8> _128()  {
    return new Tuple3<>(elem1, elem2, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T1, T8, T2> _182()  {
    return new Tuple3<>(elem1, elem8, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T8, T1, T2> _812()  {
    return new Tuple3<>(elem8, elem1, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T8, T2, T1> _821()  {
    return new Tuple3<>(elem8, elem2, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T2, T8, T1> _281()  {
    return new Tuple3<>(elem2, elem8, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T2, T1, T8> _218()  {
    return new Tuple3<>(elem2, elem1, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T1, T3, T8> _138()  {
    return new Tuple3<>(elem1, elem3, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T1, T8, T3> _183()  {
    return new Tuple3<>(elem1, elem8, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T8, T1, T3> _813()  {
    return new Tuple3<>(elem8, elem1, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T8, T3, T1> _831()  {
    return new Tuple3<>(elem8, elem3, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T3, T8, T1> _381()  {
    return new Tuple3<>(elem3, elem8, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T3, T1, T8> _318()  {
    return new Tuple3<>(elem3, elem1, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T2, T3, T8> _238()  {
    return new Tuple3<>(elem2, elem3, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T2, T8, T3> _283()  {
    return new Tuple3<>(elem2, elem8, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T8, T2, T3> _823()  {
    return new Tuple3<>(elem8, elem2, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T8, T3, T2> _832()  {
    return new Tuple3<>(elem8, elem3, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T3, T8, T2> _382()  {
    return new Tuple3<>(elem3, elem8, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T3, T2, T8> _328()  {
    return new Tuple3<>(elem3, elem2, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T1, T4, T8> _148()  {
    return new Tuple3<>(elem1, elem4, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T1, T8, T4> _184()  {
    return new Tuple3<>(elem1, elem8, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T8, T1, T4> _814()  {
    return new Tuple3<>(elem8, elem1, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T8, T4, T1> _841()  {
    return new Tuple3<>(elem8, elem4, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T4, T8, T1> _481()  {
    return new Tuple3<>(elem4, elem8, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T4, T1, T8> _418()  {
    return new Tuple3<>(elem4, elem1, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T2, T4, T8> _248()  {
    return new Tuple3<>(elem2, elem4, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T2, T8, T4> _284()  {
    return new Tuple3<>(elem2, elem8, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T8, T2, T4> _824()  {
    return new Tuple3<>(elem8, elem2, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T8, T4, T2> _842()  {
    return new Tuple3<>(elem8, elem4, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T4, T8, T2> _482()  {
    return new Tuple3<>(elem4, elem8, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T4, T2, T8> _428()  {
    return new Tuple3<>(elem4, elem2, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T3, T4, T8> _348()  {
    return new Tuple3<>(elem3, elem4, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T3, T8, T4> _384()  {
    return new Tuple3<>(elem3, elem8, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T8, T3, T4> _834()  {
    return new Tuple3<>(elem8, elem3, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T8, T4, T3> _843()  {
    return new Tuple3<>(elem8, elem4, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T4, T8, T3> _483()  {
    return new Tuple3<>(elem4, elem8, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T4, T3, T8> _438()  {
    return new Tuple3<>(elem4, elem3, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T1, T5, T8> _158()  {
    return new Tuple3<>(elem1, elem5, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T1, T8, T5> _185()  {
    return new Tuple3<>(elem1, elem8, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T8, T1, T5> _815()  {
    return new Tuple3<>(elem8, elem1, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T8, T5, T1> _851()  {
    return new Tuple3<>(elem8, elem5, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T5, T8, T1> _581()  {
    return new Tuple3<>(elem5, elem8, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T5, T1, T8> _518()  {
    return new Tuple3<>(elem5, elem1, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T2, T5, T8> _258()  {
    return new Tuple3<>(elem2, elem5, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T2, T8, T5> _285()  {
    return new Tuple3<>(elem2, elem8, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T8, T2, T5> _825()  {
    return new Tuple3<>(elem8, elem2, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T8, T5, T2> _852()  {
    return new Tuple3<>(elem8, elem5, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T5, T8, T2> _582()  {
    return new Tuple3<>(elem5, elem8, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T5, T2, T8> _528()  {
    return new Tuple3<>(elem5, elem2, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T3, T5, T8> _358()  {
    return new Tuple3<>(elem3, elem5, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T3, T8, T5> _385()  {
    return new Tuple3<>(elem3, elem8, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T8, T3, T5> _835()  {
    return new Tuple3<>(elem8, elem3, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T8, T5, T3> _853()  {
    return new Tuple3<>(elem8, elem5, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T5, T8, T3> _583()  {
    return new Tuple3<>(elem5, elem8, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T5, T3, T8> _538()  {
    return new Tuple3<>(elem5, elem3, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T4, T5, T8> _458()  {
    return new Tuple3<>(elem4, elem5, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T4, T8, T5> _485()  {
    return new Tuple3<>(elem4, elem8, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T8, T4, T5> _845()  {
    return new Tuple3<>(elem8, elem4, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T8, T5, T4> _854()  {
    return new Tuple3<>(elem8, elem5, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T5, T8, T4> _584()  {
    return new Tuple3<>(elem5, elem8, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T5, T4, T8> _548()  {
    return new Tuple3<>(elem5, elem4, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T1, T6, T8> _168()  {
    return new Tuple3<>(elem1, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T1, T8, T6> _186()  {
    return new Tuple3<>(elem1, elem8, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T8, T1, T6> _816()  {
    return new Tuple3<>(elem8, elem1, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T8, T6, T1> _861()  {
    return new Tuple3<>(elem8, elem6, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T6, T8, T1> _681()  {
    return new Tuple3<>(elem6, elem8, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T6, T1, T8> _618()  {
    return new Tuple3<>(elem6, elem1, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T2, T6, T8> _268()  {
    return new Tuple3<>(elem2, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T2, T8, T6> _286()  {
    return new Tuple3<>(elem2, elem8, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T8, T2, T6> _826()  {
    return new Tuple3<>(elem8, elem2, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T8, T6, T2> _862()  {
    return new Tuple3<>(elem8, elem6, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T6, T8, T2> _682()  {
    return new Tuple3<>(elem6, elem8, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T6, T2, T8> _628()  {
    return new Tuple3<>(elem6, elem2, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T3, T6, T8> _368()  {
    return new Tuple3<>(elem3, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T3, T8, T6> _386()  {
    return new Tuple3<>(elem3, elem8, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T8, T3, T6> _836()  {
    return new Tuple3<>(elem8, elem3, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T8, T6, T3> _863()  {
    return new Tuple3<>(elem8, elem6, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T6, T8, T3> _683()  {
    return new Tuple3<>(elem6, elem8, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T6, T3, T8> _638()  {
    return new Tuple3<>(elem6, elem3, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T4, T6, T8> _468()  {
    return new Tuple3<>(elem4, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T4, T8, T6> _486()  {
    return new Tuple3<>(elem4, elem8, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T8, T4, T6> _846()  {
    return new Tuple3<>(elem8, elem4, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T8, T6, T4> _864()  {
    return new Tuple3<>(elem8, elem6, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T6, T8, T4> _684()  {
    return new Tuple3<>(elem6, elem8, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T6, T4, T8> _648()  {
    return new Tuple3<>(elem6, elem4, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T5, T6, T8> _568()  {
    return new Tuple3<>(elem5, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T5, T8, T6> _586()  {
    return new Tuple3<>(elem5, elem8, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T8, T5, T6> _856()  {
    return new Tuple3<>(elem8, elem5, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T8, T6, T5> _865()  {
    return new Tuple3<>(elem8, elem6, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T6, T8, T5> _685()  {
    return new Tuple3<>(elem6, elem8, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T6, T5, T8> _658()  {
    return new Tuple3<>(elem6, elem5, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T1, T7, T8> _178()  {
    return new Tuple3<>(elem1, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T1, T8, T7> _187()  {
    return new Tuple3<>(elem1, elem8, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T8, T1, T7> _817()  {
    return new Tuple3<>(elem8, elem1, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T8, T7, T1> _871()  {
    return new Tuple3<>(elem8, elem7, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T7, T8, T1> _781()  {
    return new Tuple3<>(elem7, elem8, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T7, T1, T8> _718()  {
    return new Tuple3<>(elem7, elem1, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T2, T7, T8> _278()  {
    return new Tuple3<>(elem2, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T2, T8, T7> _287()  {
    return new Tuple3<>(elem2, elem8, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T8, T2, T7> _827()  {
    return new Tuple3<>(elem8, elem2, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T8, T7, T2> _872()  {
    return new Tuple3<>(elem8, elem7, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T7, T8, T2> _782()  {
    return new Tuple3<>(elem7, elem8, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T7, T2, T8> _728()  {
    return new Tuple3<>(elem7, elem2, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T3, T7, T8> _378()  {
    return new Tuple3<>(elem3, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T3, T8, T7> _387()  {
    return new Tuple3<>(elem3, elem8, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T8, T3, T7> _837()  {
    return new Tuple3<>(elem8, elem3, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T8, T7, T3> _873()  {
    return new Tuple3<>(elem8, elem7, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T7, T8, T3> _783()  {
    return new Tuple3<>(elem7, elem8, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T7, T3, T8> _738()  {
    return new Tuple3<>(elem7, elem3, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T4, T7, T8> _478()  {
    return new Tuple3<>(elem4, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T4, T8, T7> _487()  {
    return new Tuple3<>(elem4, elem8, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T8, T4, T7> _847()  {
    return new Tuple3<>(elem8, elem4, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T8, T7, T4> _874()  {
    return new Tuple3<>(elem8, elem7, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T7, T8, T4> _784()  {
    return new Tuple3<>(elem7, elem8, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T7, T4, T8> _748()  {
    return new Tuple3<>(elem7, elem4, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T5, T7, T8> _578()  {
    return new Tuple3<>(elem5, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T5, T8, T7> _587()  {
    return new Tuple3<>(elem5, elem8, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T8, T5, T7> _857()  {
    return new Tuple3<>(elem8, elem5, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T8, T7, T5> _875()  {
    return new Tuple3<>(elem8, elem7, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T7, T8, T5> _785()  {
    return new Tuple3<>(elem7, elem8, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T7, T5, T8> _758()  {
    return new Tuple3<>(elem7, elem5, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T6, T7, T8> _678()  {
    return new Tuple3<>(elem6, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T6, T8, T7> _687()  {
    return new Tuple3<>(elem6, elem8, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T8, T6, T7> _867()  {
    return new Tuple3<>(elem8, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T8, T7, T6> _876()  {
    return new Tuple3<>(elem8, elem7, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T7, T8, T6> _786()  {
    return new Tuple3<>(elem7, elem8, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T7, T6, T8> _768()  {
    return new Tuple3<>(elem7, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T1, T2, T9> _129()  {
    return new Tuple3<>(elem1, elem2, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T1, T9, T2> _192()  {
    return new Tuple3<>(elem1, elem9, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T9, T1, T2> _912()  {
    return new Tuple3<>(elem9, elem1, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T9, T2, T1> _921()  {
    return new Tuple3<>(elem9, elem2, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T2, T9, T1> _291()  {
    return new Tuple3<>(elem2, elem9, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T2, T1, T9> _219()  {
    return new Tuple3<>(elem2, elem1, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T1, T3, T9> _139()  {
    return new Tuple3<>(elem1, elem3, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T1, T9, T3> _193()  {
    return new Tuple3<>(elem1, elem9, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T9, T1, T3> _913()  {
    return new Tuple3<>(elem9, elem1, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T9, T3, T1> _931()  {
    return new Tuple3<>(elem9, elem3, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T3, T9, T1> _391()  {
    return new Tuple3<>(elem3, elem9, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T3, T1, T9> _319()  {
    return new Tuple3<>(elem3, elem1, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T2, T3, T9> _239()  {
    return new Tuple3<>(elem2, elem3, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T2, T9, T3> _293()  {
    return new Tuple3<>(elem2, elem9, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T9, T2, T3> _923()  {
    return new Tuple3<>(elem9, elem2, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T9, T3, T2> _932()  {
    return new Tuple3<>(elem9, elem3, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T3, T9, T2> _392()  {
    return new Tuple3<>(elem3, elem9, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T3, T2, T9> _329()  {
    return new Tuple3<>(elem3, elem2, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T1, T4, T9> _149()  {
    return new Tuple3<>(elem1, elem4, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T1, T9, T4> _194()  {
    return new Tuple3<>(elem1, elem9, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T9, T1, T4> _914()  {
    return new Tuple3<>(elem9, elem1, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T9, T4, T1> _941()  {
    return new Tuple3<>(elem9, elem4, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T4, T9, T1> _491()  {
    return new Tuple3<>(elem4, elem9, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T4, T1, T9> _419()  {
    return new Tuple3<>(elem4, elem1, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T2, T4, T9> _249()  {
    return new Tuple3<>(elem2, elem4, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T2, T9, T4> _294()  {
    return new Tuple3<>(elem2, elem9, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T9, T2, T4> _924()  {
    return new Tuple3<>(elem9, elem2, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T9, T4, T2> _942()  {
    return new Tuple3<>(elem9, elem4, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T4, T9, T2> _492()  {
    return new Tuple3<>(elem4, elem9, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T4, T2, T9> _429()  {
    return new Tuple3<>(elem4, elem2, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T3, T4, T9> _349()  {
    return new Tuple3<>(elem3, elem4, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T3, T9, T4> _394()  {
    return new Tuple3<>(elem3, elem9, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T9, T3, T4> _934()  {
    return new Tuple3<>(elem9, elem3, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T9, T4, T3> _943()  {
    return new Tuple3<>(elem9, elem4, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T4, T9, T3> _493()  {
    return new Tuple3<>(elem4, elem9, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T4, T3, T9> _439()  {
    return new Tuple3<>(elem4, elem3, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T1, T5, T9> _159()  {
    return new Tuple3<>(elem1, elem5, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T1, T9, T5> _195()  {
    return new Tuple3<>(elem1, elem9, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T9, T1, T5> _915()  {
    return new Tuple3<>(elem9, elem1, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T9, T5, T1> _951()  {
    return new Tuple3<>(elem9, elem5, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T5, T9, T1> _591()  {
    return new Tuple3<>(elem5, elem9, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T5, T1, T9> _519()  {
    return new Tuple3<>(elem5, elem1, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T2, T5, T9> _259()  {
    return new Tuple3<>(elem2, elem5, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T2, T9, T5> _295()  {
    return new Tuple3<>(elem2, elem9, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T9, T2, T5> _925()  {
    return new Tuple3<>(elem9, elem2, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T9, T5, T2> _952()  {
    return new Tuple3<>(elem9, elem5, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T5, T9, T2> _592()  {
    return new Tuple3<>(elem5, elem9, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T5, T2, T9> _529()  {
    return new Tuple3<>(elem5, elem2, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T3, T5, T9> _359()  {
    return new Tuple3<>(elem3, elem5, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T3, T9, T5> _395()  {
    return new Tuple3<>(elem3, elem9, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T9, T3, T5> _935()  {
    return new Tuple3<>(elem9, elem3, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T9, T5, T3> _953()  {
    return new Tuple3<>(elem9, elem5, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T5, T9, T3> _593()  {
    return new Tuple3<>(elem5, elem9, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T5, T3, T9> _539()  {
    return new Tuple3<>(elem5, elem3, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T4, T5, T9> _459()  {
    return new Tuple3<>(elem4, elem5, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T4, T9, T5> _495()  {
    return new Tuple3<>(elem4, elem9, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T9, T4, T5> _945()  {
    return new Tuple3<>(elem9, elem4, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T9, T5, T4> _954()  {
    return new Tuple3<>(elem9, elem5, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T5, T9, T4> _594()  {
    return new Tuple3<>(elem5, elem9, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T5, T4, T9> _549()  {
    return new Tuple3<>(elem5, elem4, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T1, T6, T9> _169()  {
    return new Tuple3<>(elem1, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T1, T9, T6> _196()  {
    return new Tuple3<>(elem1, elem9, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T9, T1, T6> _916()  {
    return new Tuple3<>(elem9, elem1, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T9, T6, T1> _961()  {
    return new Tuple3<>(elem9, elem6, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T6, T9, T1> _691()  {
    return new Tuple3<>(elem6, elem9, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T6, T1, T9> _619()  {
    return new Tuple3<>(elem6, elem1, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T2, T6, T9> _269()  {
    return new Tuple3<>(elem2, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T2, T9, T6> _296()  {
    return new Tuple3<>(elem2, elem9, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T9, T2, T6> _926()  {
    return new Tuple3<>(elem9, elem2, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T9, T6, T2> _962()  {
    return new Tuple3<>(elem9, elem6, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T6, T9, T2> _692()  {
    return new Tuple3<>(elem6, elem9, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T6, T2, T9> _629()  {
    return new Tuple3<>(elem6, elem2, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T3, T6, T9> _369()  {
    return new Tuple3<>(elem3, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T3, T9, T6> _396()  {
    return new Tuple3<>(elem3, elem9, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T9, T3, T6> _936()  {
    return new Tuple3<>(elem9, elem3, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T9, T6, T3> _963()  {
    return new Tuple3<>(elem9, elem6, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T6, T9, T3> _693()  {
    return new Tuple3<>(elem6, elem9, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T6, T3, T9> _639()  {
    return new Tuple3<>(elem6, elem3, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T4, T6, T9> _469()  {
    return new Tuple3<>(elem4, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T4, T9, T6> _496()  {
    return new Tuple3<>(elem4, elem9, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T9, T4, T6> _946()  {
    return new Tuple3<>(elem9, elem4, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T9, T6, T4> _964()  {
    return new Tuple3<>(elem9, elem6, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T6, T9, T4> _694()  {
    return new Tuple3<>(elem6, elem9, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T6, T4, T9> _649()  {
    return new Tuple3<>(elem6, elem4, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T5, T6, T9> _569()  {
    return new Tuple3<>(elem5, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T5, T9, T6> _596()  {
    return new Tuple3<>(elem5, elem9, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T9, T5, T6> _956()  {
    return new Tuple3<>(elem9, elem5, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T9, T6, T5> _965()  {
    return new Tuple3<>(elem9, elem6, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T6, T9, T5> _695()  {
    return new Tuple3<>(elem6, elem9, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T6, T5, T9> _659()  {
    return new Tuple3<>(elem6, elem5, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T1, T7, T9> _179()  {
    return new Tuple3<>(elem1, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T1, T9, T7> _197()  {
    return new Tuple3<>(elem1, elem9, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T9, T1, T7> _917()  {
    return new Tuple3<>(elem9, elem1, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T9, T7, T1> _971()  {
    return new Tuple3<>(elem9, elem7, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T7, T9, T1> _791()  {
    return new Tuple3<>(elem7, elem9, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T7, T1, T9> _719()  {
    return new Tuple3<>(elem7, elem1, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T2, T7, T9> _279()  {
    return new Tuple3<>(elem2, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T2, T9, T7> _297()  {
    return new Tuple3<>(elem2, elem9, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T9, T2, T7> _927()  {
    return new Tuple3<>(elem9, elem2, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T9, T7, T2> _972()  {
    return new Tuple3<>(elem9, elem7, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T7, T9, T2> _792()  {
    return new Tuple3<>(elem7, elem9, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T7, T2, T9> _729()  {
    return new Tuple3<>(elem7, elem2, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T3, T7, T9> _379()  {
    return new Tuple3<>(elem3, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T3, T9, T7> _397()  {
    return new Tuple3<>(elem3, elem9, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T9, T3, T7> _937()  {
    return new Tuple3<>(elem9, elem3, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T9, T7, T3> _973()  {
    return new Tuple3<>(elem9, elem7, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T7, T9, T3> _793()  {
    return new Tuple3<>(elem7, elem9, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T7, T3, T9> _739()  {
    return new Tuple3<>(elem7, elem3, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T4, T7, T9> _479()  {
    return new Tuple3<>(elem4, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T4, T9, T7> _497()  {
    return new Tuple3<>(elem4, elem9, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T9, T4, T7> _947()  {
    return new Tuple3<>(elem9, elem4, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T9, T7, T4> _974()  {
    return new Tuple3<>(elem9, elem7, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T7, T9, T4> _794()  {
    return new Tuple3<>(elem7, elem9, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T7, T4, T9> _749()  {
    return new Tuple3<>(elem7, elem4, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T5, T7, T9> _579()  {
    return new Tuple3<>(elem5, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T5, T9, T7> _597()  {
    return new Tuple3<>(elem5, elem9, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T9, T5, T7> _957()  {
    return new Tuple3<>(elem9, elem5, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T9, T7, T5> _975()  {
    return new Tuple3<>(elem9, elem7, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T7, T9, T5> _795()  {
    return new Tuple3<>(elem7, elem9, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T7, T5, T9> _759()  {
    return new Tuple3<>(elem7, elem5, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T6, T7, T9> _679()  {
    return new Tuple3<>(elem6, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T6, T9, T7> _697()  {
    return new Tuple3<>(elem6, elem9, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T9, T6, T7> _967()  {
    return new Tuple3<>(elem9, elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T9, T7, T6> _976()  {
    return new Tuple3<>(elem9, elem7, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T7, T9, T6> _796()  {
    return new Tuple3<>(elem7, elem9, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T7, T6, T9> _769()  {
    return new Tuple3<>(elem7, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T1, T8, T9> _189()  {
    return new Tuple3<>(elem1, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T1, T9, T8> _198()  {
    return new Tuple3<>(elem1, elem9, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T9, T1, T8> _918()  {
    return new Tuple3<>(elem9, elem1, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T9, T8, T1> _981()  {
    return new Tuple3<>(elem9, elem8, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T8, T9, T1> _891()  {
    return new Tuple3<>(elem8, elem9, elem1);
  }

  @NotNull
  @Override
  public Tuple3<T8, T1, T9> _819()  {
    return new Tuple3<>(elem8, elem1, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T2, T8, T9> _289()  {
    return new Tuple3<>(elem2, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T2, T9, T8> _298()  {
    return new Tuple3<>(elem2, elem9, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T9, T2, T8> _928()  {
    return new Tuple3<>(elem9, elem2, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T9, T8, T2> _982()  {
    return new Tuple3<>(elem9, elem8, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T8, T9, T2> _892()  {
    return new Tuple3<>(elem8, elem9, elem2);
  }

  @NotNull
  @Override
  public Tuple3<T8, T2, T9> _829()  {
    return new Tuple3<>(elem8, elem2, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T3, T8, T9> _389()  {
    return new Tuple3<>(elem3, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T3, T9, T8> _398()  {
    return new Tuple3<>(elem3, elem9, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T9, T3, T8> _938()  {
    return new Tuple3<>(elem9, elem3, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T9, T8, T3> _983()  {
    return new Tuple3<>(elem9, elem8, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T8, T9, T3> _893()  {
    return new Tuple3<>(elem8, elem9, elem3);
  }

  @NotNull
  @Override
  public Tuple3<T8, T3, T9> _839()  {
    return new Tuple3<>(elem8, elem3, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T4, T8, T9> _489()  {
    return new Tuple3<>(elem4, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T4, T9, T8> _498()  {
    return new Tuple3<>(elem4, elem9, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T9, T4, T8> _948()  {
    return new Tuple3<>(elem9, elem4, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T9, T8, T4> _984()  {
    return new Tuple3<>(elem9, elem8, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T8, T9, T4> _894()  {
    return new Tuple3<>(elem8, elem9, elem4);
  }

  @NotNull
  @Override
  public Tuple3<T8, T4, T9> _849()  {
    return new Tuple3<>(elem8, elem4, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T5, T8, T9> _589()  {
    return new Tuple3<>(elem5, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T5, T9, T8> _598()  {
    return new Tuple3<>(elem5, elem9, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T9, T5, T8> _958()  {
    return new Tuple3<>(elem9, elem5, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T9, T8, T5> _985()  {
    return new Tuple3<>(elem9, elem8, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T8, T9, T5> _895()  {
    return new Tuple3<>(elem8, elem9, elem5);
  }

  @NotNull
  @Override
  public Tuple3<T8, T5, T9> _859()  {
    return new Tuple3<>(elem8, elem5, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T6, T8, T9> _689()  {
    return new Tuple3<>(elem6, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T6, T9, T8> _698()  {
    return new Tuple3<>(elem6, elem9, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T9, T6, T8> _968()  {
    return new Tuple3<>(elem9, elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T9, T8, T6> _986()  {
    return new Tuple3<>(elem9, elem8, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T8, T9, T6> _896()  {
    return new Tuple3<>(elem8, elem9, elem6);
  }

  @NotNull
  @Override
  public Tuple3<T8, T6, T9> _869()  {
    return new Tuple3<>(elem8, elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T7, T8, T9> _789()  {
    return new Tuple3<>(elem7, elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple3<T7, T9, T8> _798()  {
    return new Tuple3<>(elem7, elem9, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T9, T7, T8> _978()  {
    return new Tuple3<>(elem9, elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple3<T9, T8, T7> _987()  {
    return new Tuple3<>(elem9, elem8, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T8, T9, T7> _897()  {
    return new Tuple3<>(elem8, elem9, elem7);
  }

  @NotNull
  @Override
  public Tuple3<T8, T7, T9> _879()  {
    return new Tuple3<>(elem8, elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple2<T1, T2> _12()  {
    return new Tuple2<>(elem1, elem2);
  }

  @NotNull
  @Override
  public Tuple2<T2, T1> _21()  {
    return new Tuple2<>(elem2, elem1);
  }

  @NotNull
  @Override
  public Tuple2<T1, T3> _13()  {
    return new Tuple2<>(elem1, elem3);
  }

  @NotNull
  @Override
  public Tuple2<T3, T1> _31()  {
    return new Tuple2<>(elem3, elem1);
  }

  @NotNull
  @Override
  public Tuple2<T2, T3> _23()  {
    return new Tuple2<>(elem2, elem3);
  }

  @NotNull
  @Override
  public Tuple2<T3, T2> _32()  {
    return new Tuple2<>(elem3, elem2);
  }

  @NotNull
  @Override
  public Tuple2<T1, T4> _14()  {
    return new Tuple2<>(elem1, elem4);
  }

  @NotNull
  @Override
  public Tuple2<T4, T1> _41()  {
    return new Tuple2<>(elem4, elem1);
  }

  @NotNull
  @Override
  public Tuple2<T2, T4> _24()  {
    return new Tuple2<>(elem2, elem4);
  }

  @NotNull
  @Override
  public Tuple2<T4, T2> _42()  {
    return new Tuple2<>(elem4, elem2);
  }

  @NotNull
  @Override
  public Tuple2<T3, T4> _34()  {
    return new Tuple2<>(elem3, elem4);
  }

  @NotNull
  @Override
  public Tuple2<T4, T3> _43()  {
    return new Tuple2<>(elem4, elem3);
  }

  @NotNull
  @Override
  public Tuple2<T1, T5> _15()  {
    return new Tuple2<>(elem1, elem5);
  }

  @NotNull
  @Override
  public Tuple2<T5, T1> _51()  {
    return new Tuple2<>(elem5, elem1);
  }

  @NotNull
  @Override
  public Tuple2<T2, T5> _25()  {
    return new Tuple2<>(elem2, elem5);
  }

  @NotNull
  @Override
  public Tuple2<T5, T2> _52()  {
    return new Tuple2<>(elem5, elem2);
  }

  @NotNull
  @Override
  public Tuple2<T3, T5> _35()  {
    return new Tuple2<>(elem3, elem5);
  }

  @NotNull
  @Override
  public Tuple2<T5, T3> _53()  {
    return new Tuple2<>(elem5, elem3);
  }

  @NotNull
  @Override
  public Tuple2<T4, T5> _45()  {
    return new Tuple2<>(elem4, elem5);
  }

  @NotNull
  @Override
  public Tuple2<T5, T4> _54()  {
    return new Tuple2<>(elem5, elem4);
  }

  @NotNull
  @Override
  public Tuple2<T1, T6> _16()  {
    return new Tuple2<>(elem1, elem6);
  }

  @NotNull
  @Override
  public Tuple2<T6, T1> _61()  {
    return new Tuple2<>(elem6, elem1);
  }

  @NotNull
  @Override
  public Tuple2<T2, T6> _26()  {
    return new Tuple2<>(elem2, elem6);
  }

  @NotNull
  @Override
  public Tuple2<T6, T2> _62()  {
    return new Tuple2<>(elem6, elem2);
  }

  @NotNull
  @Override
  public Tuple2<T3, T6> _36()  {
    return new Tuple2<>(elem3, elem6);
  }

  @NotNull
  @Override
  public Tuple2<T6, T3> _63()  {
    return new Tuple2<>(elem6, elem3);
  }

  @NotNull
  @Override
  public Tuple2<T4, T6> _46()  {
    return new Tuple2<>(elem4, elem6);
  }

  @NotNull
  @Override
  public Tuple2<T6, T4> _64()  {
    return new Tuple2<>(elem6, elem4);
  }

  @NotNull
  @Override
  public Tuple2<T5, T6> _56()  {
    return new Tuple2<>(elem5, elem6);
  }

  @NotNull
  @Override
  public Tuple2<T6, T5> _65()  {
    return new Tuple2<>(elem6, elem5);
  }

  @NotNull
  @Override
  public Tuple2<T1, T7> _17()  {
    return new Tuple2<>(elem1, elem7);
  }

  @NotNull
  @Override
  public Tuple2<T7, T1> _71()  {
    return new Tuple2<>(elem7, elem1);
  }

  @NotNull
  @Override
  public Tuple2<T2, T7> _27()  {
    return new Tuple2<>(elem2, elem7);
  }

  @NotNull
  @Override
  public Tuple2<T7, T2> _72()  {
    return new Tuple2<>(elem7, elem2);
  }

  @NotNull
  @Override
  public Tuple2<T3, T7> _37()  {
    return new Tuple2<>(elem3, elem7);
  }

  @NotNull
  @Override
  public Tuple2<T7, T3> _73()  {
    return new Tuple2<>(elem7, elem3);
  }

  @NotNull
  @Override
  public Tuple2<T4, T7> _47()  {
    return new Tuple2<>(elem4, elem7);
  }

  @NotNull
  @Override
  public Tuple2<T7, T4> _74()  {
    return new Tuple2<>(elem7, elem4);
  }

  @NotNull
  @Override
  public Tuple2<T5, T7> _57()  {
    return new Tuple2<>(elem5, elem7);
  }

  @NotNull
  @Override
  public Tuple2<T7, T5> _75()  {
    return new Tuple2<>(elem7, elem5);
  }

  @NotNull
  @Override
  public Tuple2<T6, T7> _67()  {
    return new Tuple2<>(elem6, elem7);
  }

  @NotNull
  @Override
  public Tuple2<T7, T6> _76()  {
    return new Tuple2<>(elem7, elem6);
  }

  @NotNull
  @Override
  public Tuple2<T1, T8> _18()  {
    return new Tuple2<>(elem1, elem8);
  }

  @NotNull
  @Override
  public Tuple2<T8, T1> _81()  {
    return new Tuple2<>(elem8, elem1);
  }

  @NotNull
  @Override
  public Tuple2<T2, T8> _28()  {
    return new Tuple2<>(elem2, elem8);
  }

  @NotNull
  @Override
  public Tuple2<T8, T2> _82()  {
    return new Tuple2<>(elem8, elem2);
  }

  @NotNull
  @Override
  public Tuple2<T3, T8> _38()  {
    return new Tuple2<>(elem3, elem8);
  }

  @NotNull
  @Override
  public Tuple2<T8, T3> _83()  {
    return new Tuple2<>(elem8, elem3);
  }

  @NotNull
  @Override
  public Tuple2<T4, T8> _48()  {
    return new Tuple2<>(elem4, elem8);
  }

  @NotNull
  @Override
  public Tuple2<T8, T4> _84()  {
    return new Tuple2<>(elem8, elem4);
  }

  @NotNull
  @Override
  public Tuple2<T5, T8> _58()  {
    return new Tuple2<>(elem5, elem8);
  }

  @NotNull
  @Override
  public Tuple2<T8, T5> _85()  {
    return new Tuple2<>(elem8, elem5);
  }

  @NotNull
  @Override
  public Tuple2<T6, T8> _68()  {
    return new Tuple2<>(elem6, elem8);
  }

  @NotNull
  @Override
  public Tuple2<T8, T6> _86()  {
    return new Tuple2<>(elem8, elem6);
  }

  @NotNull
  @Override
  public Tuple2<T7, T8> _78()  {
    return new Tuple2<>(elem7, elem8);
  }

  @NotNull
  @Override
  public Tuple2<T8, T7> _87()  {
    return new Tuple2<>(elem8, elem7);
  }

  @NotNull
  @Override
  public Tuple2<T1, T9> _19()  {
    return new Tuple2<>(elem1, elem9);
  }

  @NotNull
  @Override
  public Tuple2<T9, T1> _91()  {
    return new Tuple2<>(elem9, elem1);
  }

  @NotNull
  @Override
  public Tuple2<T2, T9> _29()  {
    return new Tuple2<>(elem2, elem9);
  }

  @NotNull
  @Override
  public Tuple2<T9, T2> _92()  {
    return new Tuple2<>(elem9, elem2);
  }

  @NotNull
  @Override
  public Tuple2<T3, T9> _39()  {
    return new Tuple2<>(elem3, elem9);
  }

  @NotNull
  @Override
  public Tuple2<T9, T3> _93()  {
    return new Tuple2<>(elem9, elem3);
  }

  @NotNull
  @Override
  public Tuple2<T4, T9> _49()  {
    return new Tuple2<>(elem4, elem9);
  }

  @NotNull
  @Override
  public Tuple2<T9, T4> _94()  {
    return new Tuple2<>(elem9, elem4);
  }

  @NotNull
  @Override
  public Tuple2<T5, T9> _59()  {
    return new Tuple2<>(elem5, elem9);
  }

  @NotNull
  @Override
  public Tuple2<T9, T5> _95()  {
    return new Tuple2<>(elem9, elem5);
  }

  @NotNull
  @Override
  public Tuple2<T6, T9> _69()  {
    return new Tuple2<>(elem6, elem9);
  }

  @NotNull
  @Override
  public Tuple2<T9, T6> _96()  {
    return new Tuple2<>(elem9, elem6);
  }

  @NotNull
  @Override
  public Tuple2<T7, T9> _79()  {
    return new Tuple2<>(elem7, elem9);
  }

  @NotNull
  @Override
  public Tuple2<T9, T7> _97()  {
    return new Tuple2<>(elem9, elem7);
  }

  @NotNull
  @Override
  public Tuple2<T8, T9> _89()  {
    return new Tuple2<>(elem8, elem9);
  }

  @NotNull
  @Override
  public Tuple2<T9, T8> _98()  {
    return new Tuple2<>(elem9, elem8);
  }

  @NotNull
  @Override
  public Tuple9<T1, T2, T3, T4, T5, T6, T7, T8, T9> frozenNotNull()
  {
    return this;
  }

  /**
   * Create a 9-tuple from this one where the first element is exchanged. 
   * @param e1 new first element
   * @return tuple with exchanged element
   * @param <E1> type of exchanged first element
   */
  @NotNull
  public <E1> Tuple9<E1, T2, T3, T4, T5, T6, T7, T8, T9> x1(@NotNull E1 e1)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, elem5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second element is exchanged. 
   * @param e2 new second element
   * @return tuple with exchanged element
   * @param <E2> type of exchanged second element
   */
  @NotNull
  public <E2> Tuple9<T1, E2, T3, T4, T5, T6, T7, T8, T9> x2(@NotNull E2 e2)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, elem5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third element is exchanged. 
   * @param e3 new third element
   * @return tuple with exchanged element
   * @param <E3> type of exchanged third element
   */
  @NotNull
  public <E3> Tuple9<T1, T2, E3, T4, T5, T6, T7, T8, T9> x3(@NotNull E3 e3)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, elem5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fourth element is exchanged. 
   * @param e4 new fourth element
   * @return tuple with exchanged element
   * @param <E4> type of exchanged fourth element
   */
  @NotNull
  public <E4> Tuple9<T1, T2, T3, E4, T5, T6, T7, T8, T9> x4(@NotNull E4 e4)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, elem5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fifth element is exchanged. 
   * @param e5 new fifth element
   * @return tuple with exchanged element
   * @param <E5> type of exchanged fifth element
   */
  @NotNull
  public <E5> Tuple9<T1, T2, T3, T4, E5, T6, T7, T8, T9> x5(@NotNull E5 e5)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, e5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the sixth element is exchanged. 
   * @param e6 new sixth element
   * @return tuple with exchanged element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E6> Tuple9<T1, T2, T3, T4, T5, E6, T7, T8, T9> x6(@NotNull E6 e6)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, elem5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the seventh element is exchanged. 
   * @param e7 new seventh element
   * @return tuple with exchanged element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E7> Tuple9<T1, T2, T3, T4, T5, T6, E7, T8, T9> x7(@NotNull E7 e7)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, elem5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the eighth element is exchanged. 
   * @param e8 new eighth element
   * @return tuple with exchanged element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E8> Tuple9<T1, T2, T3, T4, T5, T6, T7, E8, T9> x8(@NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, elem5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the nineth element is exchanged. 
   * @param e9 new nineth element
   * @return tuple with exchanged element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E9> Tuple9<T1, T2, T3, T4, T5, T6, T7, T8, E9> x9(@NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, elem5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first and second elements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   */
  @NotNull
  public <E1, E2> Tuple9<E1, E2, T3, T4, T5, T6, T7, T8, T9> x12(@NotNull E1 e1, @NotNull E2 e2)  {
    return new Tuple9<>(e1, e2, elem3, elem4, elem5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first and third elements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   */
  @NotNull
  public <E1, E3> Tuple9<E1, T2, E3, T4, T5, T6, T7, T8, T9> x13(@NotNull E1 e1, @NotNull E3 e3)  {
    return new Tuple9<>(e1, elem2, e3, elem4, elem5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second and third elements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   */
  @NotNull
  public <E2, E3> Tuple9<T1, E2, E3, T4, T5, T6, T7, T8, T9> x23(@NotNull E2 e2, @NotNull E3 e3)  {
    return new Tuple9<>(elem1, e2, e3, elem4, elem5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first and fourth elements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   */
  @NotNull
  public <E1, E4> Tuple9<E1, T2, T3, E4, T5, T6, T7, T8, T9> x14(@NotNull E1 e1, @NotNull E4 e4)  {
    return new Tuple9<>(e1, elem2, elem3, e4, elem5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second and fourth elements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   */
  @NotNull
  public <E2, E4> Tuple9<T1, E2, T3, E4, T5, T6, T7, T8, T9> x24(@NotNull E2 e2, @NotNull E4 e4)  {
    return new Tuple9<>(elem1, e2, elem3, e4, elem5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third and fourth elements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   */
  @NotNull
  public <E3, E4> Tuple9<T1, T2, E3, E4, T5, T6, T7, T8, T9> x34(@NotNull E3 e3, @NotNull E4 e4)  {
    return new Tuple9<>(elem1, elem2, e3, e4, elem5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first and fifth elements are exchanged. 
   * @param e1 new first element
   * @param e5 new fifth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E5> type of exchanged fifth element
   */
  @NotNull
  public <E1, E5> Tuple9<E1, T2, T3, T4, E5, T6, T7, T8, T9> x15(@NotNull E1 e1, @NotNull E5 e5)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, e5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second and fifth elements are exchanged. 
   * @param e2 new second element
   * @param e5 new fifth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   */
  @NotNull
  public <E2, E5> Tuple9<T1, E2, T3, T4, E5, T6, T7, T8, T9> x25(@NotNull E2 e2, @NotNull E5 e5)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, e5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third and fifth elements are exchanged. 
   * @param e3 new third element
   * @param e5 new fifth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   */
  @NotNull
  public <E3, E5> Tuple9<T1, T2, E3, T4, E5, T6, T7, T8, T9> x35(@NotNull E3 e3, @NotNull E5 e5)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, e5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fourth and fifth elements are exchanged. 
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   */
  @NotNull
  public <E4, E5> Tuple9<T1, T2, T3, E4, E5, T6, T7, T8, T9> x45(@NotNull E4 e4, @NotNull E5 e5)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, e5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first and sixth elements are exchanged. 
   * @param e1 new first element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E1, E6> Tuple9<E1, T2, T3, T4, T5, E6, T7, T8, T9> x16(@NotNull E1 e1, @NotNull E6 e6)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, elem5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second and sixth elements are exchanged. 
   * @param e2 new second element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E2, E6> Tuple9<T1, E2, T3, T4, T5, E6, T7, T8, T9> x26(@NotNull E2 e2, @NotNull E6 e6)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, elem5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third and sixth elements are exchanged. 
   * @param e3 new third element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E3, E6> Tuple9<T1, T2, E3, T4, T5, E6, T7, T8, T9> x36(@NotNull E3 e3, @NotNull E6 e6)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, elem5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fourth and sixth elements are exchanged. 
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E4, E6> Tuple9<T1, T2, T3, E4, T5, E6, T7, T8, T9> x46(@NotNull E4 e4, @NotNull E6 e6)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, elem5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fifth and sixth elements are exchanged. 
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E5, E6> Tuple9<T1, T2, T3, T4, E5, E6, T7, T8, T9> x56(@NotNull E5 e5, @NotNull E6 e6)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, e5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first and seventh elements are exchanged. 
   * @param e1 new first element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E7> Tuple9<E1, T2, T3, T4, T5, T6, E7, T8, T9> x17(@NotNull E1 e1, @NotNull E7 e7)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, elem5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second and seventh elements are exchanged. 
   * @param e2 new second element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E2, E7> Tuple9<T1, E2, T3, T4, T5, T6, E7, T8, T9> x27(@NotNull E2 e2, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, elem5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third and seventh elements are exchanged. 
   * @param e3 new third element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E3, E7> Tuple9<T1, T2, E3, T4, T5, T6, E7, T8, T9> x37(@NotNull E3 e3, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, elem5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fourth and seventh elements are exchanged. 
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E4, E7> Tuple9<T1, T2, T3, E4, T5, T6, E7, T8, T9> x47(@NotNull E4 e4, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, elem5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fifth and seventh elements are exchanged. 
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E5, E7> Tuple9<T1, T2, T3, T4, E5, T6, E7, T8, T9> x57(@NotNull E5 e5, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, e5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the sixth and seventh elements are exchanged. 
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E6, E7> Tuple9<T1, T2, T3, T4, T5, E6, E7, T8, T9> x67(@NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, elem5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first and eighth elements are exchanged. 
   * @param e1 new first element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E8> Tuple9<E1, T2, T3, T4, T5, T6, T7, E8, T9> x18(@NotNull E1 e1, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, elem5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second and eighth elements are exchanged. 
   * @param e2 new second element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E8> Tuple9<T1, E2, T3, T4, T5, T6, T7, E8, T9> x28(@NotNull E2 e2, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, elem5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third and eighth elements are exchanged. 
   * @param e3 new third element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E3, E8> Tuple9<T1, T2, E3, T4, T5, T6, T7, E8, T9> x38(@NotNull E3 e3, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, elem5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fourth and eighth elements are exchanged. 
   * @param e4 new fourth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E4, E8> Tuple9<T1, T2, T3, E4, T5, T6, T7, E8, T9> x48(@NotNull E4 e4, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, elem5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fifth and eighth elements are exchanged. 
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E5, E8> Tuple9<T1, T2, T3, T4, E5, T6, T7, E8, T9> x58(@NotNull E5 e5, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, e5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the sixth and eighth elements are exchanged. 
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E6, E8> Tuple9<T1, T2, T3, T4, T5, E6, T7, E8, T9> x68(@NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, elem5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the seventh and eighth elements are exchanged. 
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E7, E8> Tuple9<T1, T2, T3, T4, T5, T6, E7, E8, T9> x78(@NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, elem5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first and nineth elements are exchanged. 
   * @param e1 new first element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E9> Tuple9<E1, T2, T3, T4, T5, T6, T7, T8, E9> x19(@NotNull E1 e1, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, elem5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second and nineth elements are exchanged. 
   * @param e2 new second element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E9> Tuple9<T1, E2, T3, T4, T5, T6, T7, T8, E9> x29(@NotNull E2 e2, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, elem5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third and nineth elements are exchanged. 
   * @param e3 new third element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E9> Tuple9<T1, T2, E3, T4, T5, T6, T7, T8, E9> x39(@NotNull E3 e3, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, elem5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fourth and nineth elements are exchanged. 
   * @param e4 new fourth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E4, E9> Tuple9<T1, T2, T3, E4, T5, T6, T7, T8, E9> x49(@NotNull E4 e4, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, elem5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fifth and nineth elements are exchanged. 
   * @param e5 new fifth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E5> type of exchanged fifth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E5, E9> Tuple9<T1, T2, T3, T4, E5, T6, T7, T8, E9> x59(@NotNull E5 e5, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, e5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the sixth and nineth elements are exchanged. 
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E6, E9> Tuple9<T1, T2, T3, T4, T5, E6, T7, T8, E9> x69(@NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, elem5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the seventh and nineth elements are exchanged. 
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E7, E9> Tuple9<T1, T2, T3, T4, T5, T6, E7, T8, E9> x79(@NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, elem5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the eighth and nineth elements are exchanged. 
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E8, E9> Tuple9<T1, T2, T3, T4, T5, T6, T7, E8, E9> x89(@NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, elem5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, and thirdelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   */
  @NotNull
  public <E1, E2, E3> Tuple9<E1, E2, E3, T4, T5, T6, T7, T8, T9> x123(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3)  {
    return new Tuple9<>(e1, e2, e3, elem4, elem5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, and fourthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e4 new fourth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   */
  @NotNull
  public <E1, E2, E4> Tuple9<E1, E2, T3, E4, T5, T6, T7, T8, T9> x124(@NotNull E1 e1, @NotNull E2 e2, @NotNull E4 e4)  {
    return new Tuple9<>(e1, e2, elem3, e4, elem5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, and fourthelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e4 new fourth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   */
  @NotNull
  public <E1, E3, E4> Tuple9<E1, T2, E3, E4, T5, T6, T7, T8, T9> x134(@NotNull E1 e1, @NotNull E3 e3, @NotNull E4 e4)  {
    return new Tuple9<>(e1, elem2, e3, e4, elem5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, and fourthelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   */
  @NotNull
  public <E2, E3, E4> Tuple9<T1, E2, E3, E4, T5, T6, T7, T8, T9> x234(@NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4)  {
    return new Tuple9<>(elem1, e2, e3, e4, elem5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, and fifthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e5 new fifth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   */
  @NotNull
  public <E1, E2, E5> Tuple9<E1, E2, T3, T4, E5, T6, T7, T8, T9> x125(@NotNull E1 e1, @NotNull E2 e2, @NotNull E5 e5)  {
    return new Tuple9<>(e1, e2, elem3, elem4, e5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, and fifthelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e5 new fifth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   */
  @NotNull
  public <E1, E3, E5> Tuple9<E1, T2, E3, T4, E5, T6, T7, T8, T9> x135(@NotNull E1 e1, @NotNull E3 e3, @NotNull E5 e5)  {
    return new Tuple9<>(e1, elem2, e3, elem4, e5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, and fifthelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e5 new fifth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   */
  @NotNull
  public <E2, E3, E5> Tuple9<T1, E2, E3, T4, E5, T6, T7, T8, T9> x235(@NotNull E2 e2, @NotNull E3 e3, @NotNull E5 e5)  {
    return new Tuple9<>(elem1, e2, e3, elem4, e5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, and fifthelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   */
  @NotNull
  public <E1, E4, E5> Tuple9<E1, T2, T3, E4, E5, T6, T7, T8, T9> x145(@NotNull E1 e1, @NotNull E4 e4, @NotNull E5 e5)  {
    return new Tuple9<>(e1, elem2, elem3, e4, e5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, and fifthelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   */
  @NotNull
  public <E2, E4, E5> Tuple9<T1, E2, T3, E4, E5, T6, T7, T8, T9> x245(@NotNull E2 e2, @NotNull E4 e4, @NotNull E5 e5)  {
    return new Tuple9<>(elem1, e2, elem3, e4, e5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, and fifthelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   */
  @NotNull
  public <E3, E4, E5> Tuple9<T1, T2, E3, E4, E5, T6, T7, T8, T9> x345(@NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5)  {
    return new Tuple9<>(elem1, elem2, e3, e4, e5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, and sixthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E1, E2, E6> Tuple9<E1, E2, T3, T4, T5, E6, T7, T8, T9> x126(@NotNull E1 e1, @NotNull E2 e2, @NotNull E6 e6)  {
    return new Tuple9<>(e1, e2, elem3, elem4, elem5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, and sixthelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E1, E3, E6> Tuple9<E1, T2, E3, T4, T5, E6, T7, T8, T9> x136(@NotNull E1 e1, @NotNull E3 e3, @NotNull E6 e6)  {
    return new Tuple9<>(e1, elem2, e3, elem4, elem5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, and sixthelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E2, E3, E6> Tuple9<T1, E2, E3, T4, T5, E6, T7, T8, T9> x236(@NotNull E2 e2, @NotNull E3 e3, @NotNull E6 e6)  {
    return new Tuple9<>(elem1, e2, e3, elem4, elem5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, and sixthelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E1, E4, E6> Tuple9<E1, T2, T3, E4, T5, E6, T7, T8, T9> x146(@NotNull E1 e1, @NotNull E4 e4, @NotNull E6 e6)  {
    return new Tuple9<>(e1, elem2, elem3, e4, elem5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, and sixthelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E2, E4, E6> Tuple9<T1, E2, T3, E4, T5, E6, T7, T8, T9> x246(@NotNull E2 e2, @NotNull E4 e4, @NotNull E6 e6)  {
    return new Tuple9<>(elem1, e2, elem3, e4, elem5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, and sixthelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E3, E4, E6> Tuple9<T1, T2, E3, E4, T5, E6, T7, T8, T9> x346(@NotNull E3 e3, @NotNull E4 e4, @NotNull E6 e6)  {
    return new Tuple9<>(elem1, elem2, e3, e4, elem5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, fifth, and sixthelements are exchanged. 
   * @param e1 new first element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E1, E5, E6> Tuple9<E1, T2, T3, T4, E5, E6, T7, T8, T9> x156(@NotNull E1 e1, @NotNull E5 e5, @NotNull E6 e6)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, e5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, fifth, and sixthelements are exchanged. 
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E2, E5, E6> Tuple9<T1, E2, T3, T4, E5, E6, T7, T8, T9> x256(@NotNull E2 e2, @NotNull E5 e5, @NotNull E6 e6)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, e5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, fifth, and sixthelements are exchanged. 
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E3, E5, E6> Tuple9<T1, T2, E3, T4, E5, E6, T7, T8, T9> x356(@NotNull E3 e3, @NotNull E5 e5, @NotNull E6 e6)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, e5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, fifth, and sixthelements are exchanged. 
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E4, E5, E6> Tuple9<T1, T2, T3, E4, E5, E6, T7, T8, T9> x456(@NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, e5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E2, E7> Tuple9<E1, E2, T3, T4, T5, T6, E7, T8, T9> x127(@NotNull E1 e1, @NotNull E2 e2, @NotNull E7 e7)  {
    return new Tuple9<>(e1, e2, elem3, elem4, elem5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E3, E7> Tuple9<E1, T2, E3, T4, T5, T6, E7, T8, T9> x137(@NotNull E1 e1, @NotNull E3 e3, @NotNull E7 e7)  {
    return new Tuple9<>(e1, elem2, e3, elem4, elem5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, and seventhelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E2, E3, E7> Tuple9<T1, E2, E3, T4, T5, T6, E7, T8, T9> x237(@NotNull E2 e2, @NotNull E3 e3, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, e2, e3, elem4, elem5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E4, E7> Tuple9<E1, T2, T3, E4, T5, T6, E7, T8, T9> x147(@NotNull E1 e1, @NotNull E4 e4, @NotNull E7 e7)  {
    return new Tuple9<>(e1, elem2, elem3, e4, elem5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, and seventhelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E2, E4, E7> Tuple9<T1, E2, T3, E4, T5, T6, E7, T8, T9> x247(@NotNull E2 e2, @NotNull E4 e4, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, e2, elem3, e4, elem5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, and seventhelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E3, E4, E7> Tuple9<T1, T2, E3, E4, T5, T6, E7, T8, T9> x347(@NotNull E3 e3, @NotNull E4 e4, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, elem2, e3, e4, elem5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, fifth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E5, E7> Tuple9<E1, T2, T3, T4, E5, T6, E7, T8, T9> x157(@NotNull E1 e1, @NotNull E5 e5, @NotNull E7 e7)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, e5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, fifth, and seventhelements are exchanged. 
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E2, E5, E7> Tuple9<T1, E2, T3, T4, E5, T6, E7, T8, T9> x257(@NotNull E2 e2, @NotNull E5 e5, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, e5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, fifth, and seventhelements are exchanged. 
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E3, E5, E7> Tuple9<T1, T2, E3, T4, E5, T6, E7, T8, T9> x357(@NotNull E3 e3, @NotNull E5 e5, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, e5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, fifth, and seventhelements are exchanged. 
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E4, E5, E7> Tuple9<T1, T2, T3, E4, E5, T6, E7, T8, T9> x457(@NotNull E4 e4, @NotNull E5 e5, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, e5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, sixth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E6, E7> Tuple9<E1, T2, T3, T4, T5, E6, E7, T8, T9> x167(@NotNull E1 e1, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, elem5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, sixth, and seventhelements are exchanged. 
   * @param e2 new second element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E2, E6, E7> Tuple9<T1, E2, T3, T4, T5, E6, E7, T8, T9> x267(@NotNull E2 e2, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, elem5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, sixth, and seventhelements are exchanged. 
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E3, E6, E7> Tuple9<T1, T2, E3, T4, T5, E6, E7, T8, T9> x367(@NotNull E3 e3, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, elem5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, sixth, and seventhelements are exchanged. 
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E4, E6, E7> Tuple9<T1, T2, T3, E4, T5, E6, E7, T8, T9> x467(@NotNull E4 e4, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, elem5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fifth, sixth, and seventhelements are exchanged. 
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E5, E6, E7> Tuple9<T1, T2, T3, T4, E5, E6, E7, T8, T9> x567(@NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, e5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E2, E8> Tuple9<E1, E2, T3, T4, T5, T6, T7, E8, T9> x128(@NotNull E1 e1, @NotNull E2 e2, @NotNull E8 e8)  {
    return new Tuple9<>(e1, e2, elem3, elem4, elem5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E3, E8> Tuple9<E1, T2, E3, T4, T5, T6, T7, E8, T9> x138(@NotNull E1 e1, @NotNull E3 e3, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, e3, elem4, elem5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E3, E8> Tuple9<T1, E2, E3, T4, T5, T6, T7, E8, T9> x238(@NotNull E2 e2, @NotNull E3 e3, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, e3, elem4, elem5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E4, E8> Tuple9<E1, T2, T3, E4, T5, T6, T7, E8, T9> x148(@NotNull E1 e1, @NotNull E4 e4, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, elem3, e4, elem5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E4, E8> Tuple9<T1, E2, T3, E4, T5, T6, T7, E8, T9> x248(@NotNull E2 e2, @NotNull E4 e4, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, elem3, e4, elem5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, and eighthelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E3, E4, E8> Tuple9<T1, T2, E3, E4, T5, T6, T7, E8, T9> x348(@NotNull E3 e3, @NotNull E4 e4, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, e3, e4, elem5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, fifth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E5, E8> Tuple9<E1, T2, T3, T4, E5, T6, T7, E8, T9> x158(@NotNull E1 e1, @NotNull E5 e5, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, e5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, fifth, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E5, E8> Tuple9<T1, E2, T3, T4, E5, T6, T7, E8, T9> x258(@NotNull E2 e2, @NotNull E5 e5, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, e5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, fifth, and eighthelements are exchanged. 
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E3, E5, E8> Tuple9<T1, T2, E3, T4, E5, T6, T7, E8, T9> x358(@NotNull E3 e3, @NotNull E5 e5, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, e5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, fifth, and eighthelements are exchanged. 
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E4, E5, E8> Tuple9<T1, T2, T3, E4, E5, T6, T7, E8, T9> x458(@NotNull E4 e4, @NotNull E5 e5, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, e5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, sixth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E6, E8> Tuple9<E1, T2, T3, T4, T5, E6, T7, E8, T9> x168(@NotNull E1 e1, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, elem5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, sixth, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E6, E8> Tuple9<T1, E2, T3, T4, T5, E6, T7, E8, T9> x268(@NotNull E2 e2, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, elem5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, sixth, and eighthelements are exchanged. 
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E3, E6, E8> Tuple9<T1, T2, E3, T4, T5, E6, T7, E8, T9> x368(@NotNull E3 e3, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, elem5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, sixth, and eighthelements are exchanged. 
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E4, E6, E8> Tuple9<T1, T2, T3, E4, T5, E6, T7, E8, T9> x468(@NotNull E4 e4, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, elem5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fifth, sixth, and eighthelements are exchanged. 
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E5, E6, E8> Tuple9<T1, T2, T3, T4, E5, E6, T7, E8, T9> x568(@NotNull E5 e5, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, e5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, seventh, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E7, E8> Tuple9<E1, T2, T3, T4, T5, T6, E7, E8, T9> x178(@NotNull E1 e1, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, elem5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, seventh, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E7, E8> Tuple9<T1, E2, T3, T4, T5, T6, E7, E8, T9> x278(@NotNull E2 e2, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, elem5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, seventh, and eighthelements are exchanged. 
   * @param e3 new third element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E3, E7, E8> Tuple9<T1, T2, E3, T4, T5, T6, E7, E8, T9> x378(@NotNull E3 e3, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, elem5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, seventh, and eighthelements are exchanged. 
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E4, E7, E8> Tuple9<T1, T2, T3, E4, T5, T6, E7, E8, T9> x478(@NotNull E4 e4, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, elem5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fifth, seventh, and eighthelements are exchanged. 
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E5, E7, E8> Tuple9<T1, T2, T3, T4, E5, T6, E7, E8, T9> x578(@NotNull E5 e5, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, e5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the sixth, seventh, and eighthelements are exchanged. 
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E6, E7, E8> Tuple9<T1, T2, T3, T4, T5, E6, E7, E8, T9> x678(@NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, elem5, e6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E9> Tuple9<E1, E2, T3, T4, T5, T6, T7, T8, E9> x129(@NotNull E1 e1, @NotNull E2 e2, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, elem3, elem4, elem5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E3, E9> Tuple9<E1, T2, E3, T4, T5, T6, T7, T8, E9> x139(@NotNull E1 e1, @NotNull E3 e3, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, e3, elem4, elem5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E3, E9> Tuple9<T1, E2, E3, T4, T5, T6, T7, T8, E9> x239(@NotNull E2 e2, @NotNull E3 e3, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, e3, elem4, elem5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E4, E9> Tuple9<E1, T2, T3, E4, T5, T6, T7, T8, E9> x149(@NotNull E1 e1, @NotNull E4 e4, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, e4, elem5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E4, E9> Tuple9<T1, E2, T3, E4, T5, T6, T7, T8, E9> x249(@NotNull E2 e2, @NotNull E4 e4, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, e4, elem5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E4, E9> Tuple9<T1, T2, E3, E4, T5, T6, T7, T8, E9> x349(@NotNull E3 e3, @NotNull E4 e4, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, e4, elem5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, fifth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e5 new fifth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E5> type of exchanged fifth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E5, E9> Tuple9<E1, T2, T3, T4, E5, T6, T7, T8, E9> x159(@NotNull E1 e1, @NotNull E5 e5, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, e5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, fifth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E5, E9> Tuple9<T1, E2, T3, T4, E5, T6, T7, T8, E9> x259(@NotNull E2 e2, @NotNull E5 e5, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, e5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, fifth, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E5, E9> Tuple9<T1, T2, E3, T4, E5, T6, T7, T8, E9> x359(@NotNull E3 e3, @NotNull E5 e5, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, e5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, fifth, and ninethelements are exchanged. 
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E4, E5, E9> Tuple9<T1, T2, T3, E4, E5, T6, T7, T8, E9> x459(@NotNull E4 e4, @NotNull E5 e5, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, e5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, sixth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E6, E9> Tuple9<E1, T2, T3, T4, T5, E6, T7, T8, E9> x169(@NotNull E1 e1, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, elem5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, sixth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E6, E9> Tuple9<T1, E2, T3, T4, T5, E6, T7, T8, E9> x269(@NotNull E2 e2, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, elem5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, sixth, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E6, E9> Tuple9<T1, T2, E3, T4, T5, E6, T7, T8, E9> x369(@NotNull E3 e3, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, elem5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, sixth, and ninethelements are exchanged. 
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E4, E6, E9> Tuple9<T1, T2, T3, E4, T5, E6, T7, T8, E9> x469(@NotNull E4 e4, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, elem5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fifth, sixth, and ninethelements are exchanged. 
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E5, E6, E9> Tuple9<T1, T2, T3, T4, E5, E6, T7, T8, E9> x569(@NotNull E5 e5, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, e5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, seventh, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E7, E9> Tuple9<E1, T2, T3, T4, T5, T6, E7, T8, E9> x179(@NotNull E1 e1, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, elem5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, seventh, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E7, E9> Tuple9<T1, E2, T3, T4, T5, T6, E7, T8, E9> x279(@NotNull E2 e2, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, elem5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, seventh, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E7, E9> Tuple9<T1, T2, E3, T4, T5, T6, E7, T8, E9> x379(@NotNull E3 e3, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, elem5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, seventh, and ninethelements are exchanged. 
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E4, E7, E9> Tuple9<T1, T2, T3, E4, T5, T6, E7, T8, E9> x479(@NotNull E4 e4, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, elem5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fifth, seventh, and ninethelements are exchanged. 
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E5, E7, E9> Tuple9<T1, T2, T3, T4, E5, T6, E7, T8, E9> x579(@NotNull E5 e5, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, e5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the sixth, seventh, and ninethelements are exchanged. 
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E6, E7, E9> Tuple9<T1, T2, T3, T4, T5, E6, E7, T8, E9> x679(@NotNull E6 e6, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, elem5, e6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E8, E9> Tuple9<E1, T2, T3, T4, T5, T6, T7, E8, E9> x189(@NotNull E1 e1, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, elem5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, eighth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E8, E9> Tuple9<T1, E2, T3, T4, T5, T6, T7, E8, E9> x289(@NotNull E2 e2, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, elem5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, eighth, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E8, E9> Tuple9<T1, T2, E3, T4, T5, T6, T7, E8, E9> x389(@NotNull E3 e3, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, elem5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, eighth, and ninethelements are exchanged. 
   * @param e4 new fourth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E4, E8, E9> Tuple9<T1, T2, T3, E4, T5, T6, T7, E8, E9> x489(@NotNull E4 e4, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, elem5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fifth, eighth, and ninethelements are exchanged. 
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E5, E8, E9> Tuple9<T1, T2, T3, T4, E5, T6, T7, E8, E9> x589(@NotNull E5 e5, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, e5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the sixth, eighth, and ninethelements are exchanged. 
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E6, E8, E9> Tuple9<T1, T2, T3, T4, T5, E6, T7, E8, E9> x689(@NotNull E6 e6, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, elem5, e6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the seventh, eighth, and ninethelements are exchanged. 
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E7, E8, E9> Tuple9<T1, T2, T3, T4, T5, T6, E7, E8, E9> x789(@NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, elem5, elem6, e7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, third, and fourthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   */
  @NotNull
  public <E1, E2, E3, E4> Tuple9<E1, E2, E3, E4, T5, T6, T7, T8, T9> x1234(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4)  {
    return new Tuple9<>(e1, e2, e3, e4, elem5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, third, and fifthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @param e5 new fifth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   */
  @NotNull
  public <E1, E2, E3, E5> Tuple9<E1, E2, E3, T4, E5, T6, T7, T8, T9> x1235(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3, @NotNull E5 e5)  {
    return new Tuple9<>(e1, e2, e3, elem4, e5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fourth, and fifthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   */
  @NotNull
  public <E1, E2, E4, E5> Tuple9<E1, E2, T3, E4, E5, T6, T7, T8, T9> x1245(@NotNull E1 e1, @NotNull E2 e2, @NotNull E4 e4, @NotNull E5 e5)  {
    return new Tuple9<>(e1, e2, elem3, e4, e5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fourth, and fifthelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   */
  @NotNull
  public <E1, E3, E4, E5> Tuple9<E1, T2, E3, E4, E5, T6, T7, T8, T9> x1345(@NotNull E1 e1, @NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5)  {
    return new Tuple9<>(e1, elem2, e3, e4, e5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fourth, and fifthelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   */
  @NotNull
  public <E2, E3, E4, E5> Tuple9<T1, E2, E3, E4, E5, T6, T7, T8, T9> x2345(@NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5)  {
    return new Tuple9<>(elem1, e2, e3, e4, e5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, third, and sixthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E1, E2, E3, E6> Tuple9<E1, E2, E3, T4, T5, E6, T7, T8, T9> x1236(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3, @NotNull E6 e6)  {
    return new Tuple9<>(e1, e2, e3, elem4, elem5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fourth, and sixthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E1, E2, E4, E6> Tuple9<E1, E2, T3, E4, T5, E6, T7, T8, T9> x1246(@NotNull E1 e1, @NotNull E2 e2, @NotNull E4 e4, @NotNull E6 e6)  {
    return new Tuple9<>(e1, e2, elem3, e4, elem5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fourth, and sixthelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E1, E3, E4, E6> Tuple9<E1, T2, E3, E4, T5, E6, T7, T8, T9> x1346(@NotNull E1 e1, @NotNull E3 e3, @NotNull E4 e4, @NotNull E6 e6)  {
    return new Tuple9<>(e1, elem2, e3, e4, elem5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fourth, and sixthelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E2, E3, E4, E6> Tuple9<T1, E2, E3, E4, T5, E6, T7, T8, T9> x2346(@NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4, @NotNull E6 e6)  {
    return new Tuple9<>(elem1, e2, e3, e4, elem5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fifth, and sixthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E1, E2, E5, E6> Tuple9<E1, E2, T3, T4, E5, E6, T7, T8, T9> x1256(@NotNull E1 e1, @NotNull E2 e2, @NotNull E5 e5, @NotNull E6 e6)  {
    return new Tuple9<>(e1, e2, elem3, elem4, e5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fifth, and sixthelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E1, E3, E5, E6> Tuple9<E1, T2, E3, T4, E5, E6, T7, T8, T9> x1356(@NotNull E1 e1, @NotNull E3 e3, @NotNull E5 e5, @NotNull E6 e6)  {
    return new Tuple9<>(e1, elem2, e3, elem4, e5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fifth, and sixthelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E2, E3, E5, E6> Tuple9<T1, E2, E3, T4, E5, E6, T7, T8, T9> x2356(@NotNull E2 e2, @NotNull E3 e3, @NotNull E5 e5, @NotNull E6 e6)  {
    return new Tuple9<>(elem1, e2, e3, elem4, e5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, fifth, and sixthelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E1, E4, E5, E6> Tuple9<E1, T2, T3, E4, E5, E6, T7, T8, T9> x1456(@NotNull E1 e1, @NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6)  {
    return new Tuple9<>(e1, elem2, elem3, e4, e5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, fifth, and sixthelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E2, E4, E5, E6> Tuple9<T1, E2, T3, E4, E5, E6, T7, T8, T9> x2456(@NotNull E2 e2, @NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6)  {
    return new Tuple9<>(elem1, e2, elem3, e4, e5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, fifth, and sixthelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E3, E4, E5, E6> Tuple9<T1, T2, E3, E4, E5, E6, T7, T8, T9> x3456(@NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6)  {
    return new Tuple9<>(elem1, elem2, e3, e4, e5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, third, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E2, E3, E7> Tuple9<E1, E2, E3, T4, T5, T6, E7, T8, T9> x1237(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3, @NotNull E7 e7)  {
    return new Tuple9<>(e1, e2, e3, elem4, elem5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fourth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E2, E4, E7> Tuple9<E1, E2, T3, E4, T5, T6, E7, T8, T9> x1247(@NotNull E1 e1, @NotNull E2 e2, @NotNull E4 e4, @NotNull E7 e7)  {
    return new Tuple9<>(e1, e2, elem3, e4, elem5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fourth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E3, E4, E7> Tuple9<E1, T2, E3, E4, T5, T6, E7, T8, T9> x1347(@NotNull E1 e1, @NotNull E3 e3, @NotNull E4 e4, @NotNull E7 e7)  {
    return new Tuple9<>(e1, elem2, e3, e4, elem5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fourth, and seventhelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E2, E3, E4, E7> Tuple9<T1, E2, E3, E4, T5, T6, E7, T8, T9> x2347(@NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, e2, e3, e4, elem5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fifth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E2, E5, E7> Tuple9<E1, E2, T3, T4, E5, T6, E7, T8, T9> x1257(@NotNull E1 e1, @NotNull E2 e2, @NotNull E5 e5, @NotNull E7 e7)  {
    return new Tuple9<>(e1, e2, elem3, elem4, e5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fifth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E3, E5, E7> Tuple9<E1, T2, E3, T4, E5, T6, E7, T8, T9> x1357(@NotNull E1 e1, @NotNull E3 e3, @NotNull E5 e5, @NotNull E7 e7)  {
    return new Tuple9<>(e1, elem2, e3, elem4, e5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fifth, and seventhelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E2, E3, E5, E7> Tuple9<T1, E2, E3, T4, E5, T6, E7, T8, T9> x2357(@NotNull E2 e2, @NotNull E3 e3, @NotNull E5 e5, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, e2, e3, elem4, e5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, fifth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E4, E5, E7> Tuple9<E1, T2, T3, E4, E5, T6, E7, T8, T9> x1457(@NotNull E1 e1, @NotNull E4 e4, @NotNull E5 e5, @NotNull E7 e7)  {
    return new Tuple9<>(e1, elem2, elem3, e4, e5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, fifth, and seventhelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E2, E4, E5, E7> Tuple9<T1, E2, T3, E4, E5, T6, E7, T8, T9> x2457(@NotNull E2 e2, @NotNull E4 e4, @NotNull E5 e5, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, e2, elem3, e4, e5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, fifth, and seventhelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E3, E4, E5, E7> Tuple9<T1, T2, E3, E4, E5, T6, E7, T8, T9> x3457(@NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, elem2, e3, e4, e5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, sixth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E2, E6, E7> Tuple9<E1, E2, T3, T4, T5, E6, E7, T8, T9> x1267(@NotNull E1 e1, @NotNull E2 e2, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(e1, e2, elem3, elem4, elem5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, sixth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E3, E6, E7> Tuple9<E1, T2, E3, T4, T5, E6, E7, T8, T9> x1367(@NotNull E1 e1, @NotNull E3 e3, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(e1, elem2, e3, elem4, elem5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, sixth, and seventhelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E2, E3, E6, E7> Tuple9<T1, E2, E3, T4, T5, E6, E7, T8, T9> x2367(@NotNull E2 e2, @NotNull E3 e3, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, e2, e3, elem4, elem5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, sixth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E4, E6, E7> Tuple9<E1, T2, T3, E4, T5, E6, E7, T8, T9> x1467(@NotNull E1 e1, @NotNull E4 e4, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(e1, elem2, elem3, e4, elem5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, sixth, and seventhelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E2, E4, E6, E7> Tuple9<T1, E2, T3, E4, T5, E6, E7, T8, T9> x2467(@NotNull E2 e2, @NotNull E4 e4, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, e2, elem3, e4, elem5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, sixth, and seventhelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E3, E4, E6, E7> Tuple9<T1, T2, E3, E4, T5, E6, E7, T8, T9> x3467(@NotNull E3 e3, @NotNull E4 e4, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, elem2, e3, e4, elem5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, fifth, sixth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E5, E6, E7> Tuple9<E1, T2, T3, T4, E5, E6, E7, T8, T9> x1567(@NotNull E1 e1, @NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, e5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, fifth, sixth, and seventhelements are exchanged. 
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E2, E5, E6, E7> Tuple9<T1, E2, T3, T4, E5, E6, E7, T8, T9> x2567(@NotNull E2 e2, @NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, e5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, fifth, sixth, and seventhelements are exchanged. 
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E3, E5, E6, E7> Tuple9<T1, T2, E3, T4, E5, E6, E7, T8, T9> x3567(@NotNull E3 e3, @NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, e5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, fifth, sixth, and seventhelements are exchanged. 
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E4, E5, E6, E7> Tuple9<T1, T2, T3, E4, E5, E6, E7, T8, T9> x4567(@NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, e5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, third, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E2, E3, E8> Tuple9<E1, E2, E3, T4, T5, T6, T7, E8, T9> x1238(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3, @NotNull E8 e8)  {
    return new Tuple9<>(e1, e2, e3, elem4, elem5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fourth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E2, E4, E8> Tuple9<E1, E2, T3, E4, T5, T6, T7, E8, T9> x1248(@NotNull E1 e1, @NotNull E2 e2, @NotNull E4 e4, @NotNull E8 e8)  {
    return new Tuple9<>(e1, e2, elem3, e4, elem5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fourth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E3, E4, E8> Tuple9<E1, T2, E3, E4, T5, T6, T7, E8, T9> x1348(@NotNull E1 e1, @NotNull E3 e3, @NotNull E4 e4, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, e3, e4, elem5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fourth, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E3, E4, E8> Tuple9<T1, E2, E3, E4, T5, T6, T7, E8, T9> x2348(@NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, e3, e4, elem5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fifth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E2, E5, E8> Tuple9<E1, E2, T3, T4, E5, T6, T7, E8, T9> x1258(@NotNull E1 e1, @NotNull E2 e2, @NotNull E5 e5, @NotNull E8 e8)  {
    return new Tuple9<>(e1, e2, elem3, elem4, e5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fifth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E3, E5, E8> Tuple9<E1, T2, E3, T4, E5, T6, T7, E8, T9> x1358(@NotNull E1 e1, @NotNull E3 e3, @NotNull E5 e5, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, e3, elem4, e5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fifth, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E3, E5, E8> Tuple9<T1, E2, E3, T4, E5, T6, T7, E8, T9> x2358(@NotNull E2 e2, @NotNull E3 e3, @NotNull E5 e5, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, e3, elem4, e5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, fifth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E4, E5, E8> Tuple9<E1, T2, T3, E4, E5, T6, T7, E8, T9> x1458(@NotNull E1 e1, @NotNull E4 e4, @NotNull E5 e5, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, elem3, e4, e5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, fifth, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E4, E5, E8> Tuple9<T1, E2, T3, E4, E5, T6, T7, E8, T9> x2458(@NotNull E2 e2, @NotNull E4 e4, @NotNull E5 e5, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, elem3, e4, e5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, fifth, and eighthelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E3, E4, E5, E8> Tuple9<T1, T2, E3, E4, E5, T6, T7, E8, T9> x3458(@NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, e3, e4, e5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, sixth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E2, E6, E8> Tuple9<E1, E2, T3, T4, T5, E6, T7, E8, T9> x1268(@NotNull E1 e1, @NotNull E2 e2, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(e1, e2, elem3, elem4, elem5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, sixth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E3, E6, E8> Tuple9<E1, T2, E3, T4, T5, E6, T7, E8, T9> x1368(@NotNull E1 e1, @NotNull E3 e3, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, e3, elem4, elem5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, sixth, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E3, E6, E8> Tuple9<T1, E2, E3, T4, T5, E6, T7, E8, T9> x2368(@NotNull E2 e2, @NotNull E3 e3, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, e3, elem4, elem5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, sixth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E4, E6, E8> Tuple9<E1, T2, T3, E4, T5, E6, T7, E8, T9> x1468(@NotNull E1 e1, @NotNull E4 e4, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, elem3, e4, elem5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, sixth, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E4, E6, E8> Tuple9<T1, E2, T3, E4, T5, E6, T7, E8, T9> x2468(@NotNull E2 e2, @NotNull E4 e4, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, elem3, e4, elem5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, sixth, and eighthelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E3, E4, E6, E8> Tuple9<T1, T2, E3, E4, T5, E6, T7, E8, T9> x3468(@NotNull E3 e3, @NotNull E4 e4, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, e3, e4, elem5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, fifth, sixth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E5, E6, E8> Tuple9<E1, T2, T3, T4, E5, E6, T7, E8, T9> x1568(@NotNull E1 e1, @NotNull E5 e5, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, e5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, fifth, sixth, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E5, E6, E8> Tuple9<T1, E2, T3, T4, E5, E6, T7, E8, T9> x2568(@NotNull E2 e2, @NotNull E5 e5, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, e5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, fifth, sixth, and eighthelements are exchanged. 
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E3, E5, E6, E8> Tuple9<T1, T2, E3, T4, E5, E6, T7, E8, T9> x3568(@NotNull E3 e3, @NotNull E5 e5, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, e5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, fifth, sixth, and eighthelements are exchanged. 
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E4, E5, E6, E8> Tuple9<T1, T2, T3, E4, E5, E6, T7, E8, T9> x4568(@NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, e5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, seventh, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E2, E7, E8> Tuple9<E1, E2, T3, T4, T5, T6, E7, E8, T9> x1278(@NotNull E1 e1, @NotNull E2 e2, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(e1, e2, elem3, elem4, elem5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, seventh, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E3, E7, E8> Tuple9<E1, T2, E3, T4, T5, T6, E7, E8, T9> x1378(@NotNull E1 e1, @NotNull E3 e3, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, e3, elem4, elem5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, seventh, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E3, E7, E8> Tuple9<T1, E2, E3, T4, T5, T6, E7, E8, T9> x2378(@NotNull E2 e2, @NotNull E3 e3, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, e3, elem4, elem5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, seventh, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E4, E7, E8> Tuple9<E1, T2, T3, E4, T5, T6, E7, E8, T9> x1478(@NotNull E1 e1, @NotNull E4 e4, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, elem3, e4, elem5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, seventh, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E4, E7, E8> Tuple9<T1, E2, T3, E4, T5, T6, E7, E8, T9> x2478(@NotNull E2 e2, @NotNull E4 e4, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, elem3, e4, elem5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, seventh, and eighthelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E3, E4, E7, E8> Tuple9<T1, T2, E3, E4, T5, T6, E7, E8, T9> x3478(@NotNull E3 e3, @NotNull E4 e4, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, e3, e4, elem5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, fifth, seventh, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E5, E7, E8> Tuple9<E1, T2, T3, T4, E5, T6, E7, E8, T9> x1578(@NotNull E1 e1, @NotNull E5 e5, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, e5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, fifth, seventh, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E5, E7, E8> Tuple9<T1, E2, T3, T4, E5, T6, E7, E8, T9> x2578(@NotNull E2 e2, @NotNull E5 e5, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, e5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, fifth, seventh, and eighthelements are exchanged. 
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E3, E5, E7, E8> Tuple9<T1, T2, E3, T4, E5, T6, E7, E8, T9> x3578(@NotNull E3 e3, @NotNull E5 e5, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, e5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, fifth, seventh, and eighthelements are exchanged. 
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E4, E5, E7, E8> Tuple9<T1, T2, T3, E4, E5, T6, E7, E8, T9> x4578(@NotNull E4 e4, @NotNull E5 e5, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, e5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, sixth, seventh, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E6, E7, E8> Tuple9<E1, T2, T3, T4, T5, E6, E7, E8, T9> x1678(@NotNull E1 e1, @NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, elem5, e6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, sixth, seventh, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E6, E7, E8> Tuple9<T1, E2, T3, T4, T5, E6, E7, E8, T9> x2678(@NotNull E2 e2, @NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, elem5, e6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, sixth, seventh, and eighthelements are exchanged. 
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E3, E6, E7, E8> Tuple9<T1, T2, E3, T4, T5, E6, E7, E8, T9> x3678(@NotNull E3 e3, @NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, elem5, e6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, sixth, seventh, and eighthelements are exchanged. 
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E4, E6, E7, E8> Tuple9<T1, T2, T3, E4, T5, E6, E7, E8, T9> x4678(@NotNull E4 e4, @NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, elem5, e6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fifth, sixth, seventh, and eighthelements are exchanged. 
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E5, E6, E7, E8> Tuple9<T1, T2, T3, T4, E5, E6, E7, E8, T9> x5678(@NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, e5, e6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, third, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E3, E9> Tuple9<E1, E2, E3, T4, T5, T6, T7, T8, E9> x1239(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, e3, elem4, elem5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fourth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E4, E9> Tuple9<E1, E2, T3, E4, T5, T6, T7, T8, E9> x1249(@NotNull E1 e1, @NotNull E2 e2, @NotNull E4 e4, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, elem3, e4, elem5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fourth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E3, E4, E9> Tuple9<E1, T2, E3, E4, T5, T6, T7, T8, E9> x1349(@NotNull E1 e1, @NotNull E3 e3, @NotNull E4 e4, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, e3, e4, elem5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fourth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E3, E4, E9> Tuple9<T1, E2, E3, E4, T5, T6, T7, T8, E9> x2349(@NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, e3, e4, elem5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fifth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E5, E9> Tuple9<E1, E2, T3, T4, E5, T6, T7, T8, E9> x1259(@NotNull E1 e1, @NotNull E2 e2, @NotNull E5 e5, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, elem3, elem4, e5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fifth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E3, E5, E9> Tuple9<E1, T2, E3, T4, E5, T6, T7, T8, E9> x1359(@NotNull E1 e1, @NotNull E3 e3, @NotNull E5 e5, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, e3, elem4, e5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fifth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E3, E5, E9> Tuple9<T1, E2, E3, T4, E5, T6, T7, T8, E9> x2359(@NotNull E2 e2, @NotNull E3 e3, @NotNull E5 e5, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, e3, elem4, e5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, fifth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E4, E5, E9> Tuple9<E1, T2, T3, E4, E5, T6, T7, T8, E9> x1459(@NotNull E1 e1, @NotNull E4 e4, @NotNull E5 e5, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, e4, e5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, fifth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E4, E5, E9> Tuple9<T1, E2, T3, E4, E5, T6, T7, T8, E9> x2459(@NotNull E2 e2, @NotNull E4 e4, @NotNull E5 e5, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, e4, e5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, fifth, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E4, E5, E9> Tuple9<T1, T2, E3, E4, E5, T6, T7, T8, E9> x3459(@NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, e4, e5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, sixth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E6, E9> Tuple9<E1, E2, T3, T4, T5, E6, T7, T8, E9> x1269(@NotNull E1 e1, @NotNull E2 e2, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, elem3, elem4, elem5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, sixth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E3, E6, E9> Tuple9<E1, T2, E3, T4, T5, E6, T7, T8, E9> x1369(@NotNull E1 e1, @NotNull E3 e3, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, e3, elem4, elem5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, sixth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E3, E6, E9> Tuple9<T1, E2, E3, T4, T5, E6, T7, T8, E9> x2369(@NotNull E2 e2, @NotNull E3 e3, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, e3, elem4, elem5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, sixth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E4, E6, E9> Tuple9<E1, T2, T3, E4, T5, E6, T7, T8, E9> x1469(@NotNull E1 e1, @NotNull E4 e4, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, e4, elem5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, sixth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E4, E6, E9> Tuple9<T1, E2, T3, E4, T5, E6, T7, T8, E9> x2469(@NotNull E2 e2, @NotNull E4 e4, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, e4, elem5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, sixth, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E4, E6, E9> Tuple9<T1, T2, E3, E4, T5, E6, T7, T8, E9> x3469(@NotNull E3 e3, @NotNull E4 e4, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, e4, elem5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, fifth, sixth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E5, E6, E9> Tuple9<E1, T2, T3, T4, E5, E6, T7, T8, E9> x1569(@NotNull E1 e1, @NotNull E5 e5, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, e5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, fifth, sixth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E5, E6, E9> Tuple9<T1, E2, T3, T4, E5, E6, T7, T8, E9> x2569(@NotNull E2 e2, @NotNull E5 e5, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, e5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, fifth, sixth, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E5, E6, E9> Tuple9<T1, T2, E3, T4, E5, E6, T7, T8, E9> x3569(@NotNull E3 e3, @NotNull E5 e5, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, e5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, fifth, sixth, and ninethelements are exchanged. 
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E4, E5, E6, E9> Tuple9<T1, T2, T3, E4, E5, E6, T7, T8, E9> x4569(@NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, e5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, seventh, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E7, E9> Tuple9<E1, E2, T3, T4, T5, T6, E7, T8, E9> x1279(@NotNull E1 e1, @NotNull E2 e2, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, elem3, elem4, elem5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, seventh, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E3, E7, E9> Tuple9<E1, T2, E3, T4, T5, T6, E7, T8, E9> x1379(@NotNull E1 e1, @NotNull E3 e3, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, e3, elem4, elem5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, seventh, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E3, E7, E9> Tuple9<T1, E2, E3, T4, T5, T6, E7, T8, E9> x2379(@NotNull E2 e2, @NotNull E3 e3, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, e3, elem4, elem5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, seventh, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E4, E7, E9> Tuple9<E1, T2, T3, E4, T5, T6, E7, T8, E9> x1479(@NotNull E1 e1, @NotNull E4 e4, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, e4, elem5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, seventh, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E4, E7, E9> Tuple9<T1, E2, T3, E4, T5, T6, E7, T8, E9> x2479(@NotNull E2 e2, @NotNull E4 e4, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, e4, elem5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, seventh, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E4, E7, E9> Tuple9<T1, T2, E3, E4, T5, T6, E7, T8, E9> x3479(@NotNull E3 e3, @NotNull E4 e4, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, e4, elem5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, fifth, seventh, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E5, E7, E9> Tuple9<E1, T2, T3, T4, E5, T6, E7, T8, E9> x1579(@NotNull E1 e1, @NotNull E5 e5, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, e5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, fifth, seventh, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E5, E7, E9> Tuple9<T1, E2, T3, T4, E5, T6, E7, T8, E9> x2579(@NotNull E2 e2, @NotNull E5 e5, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, e5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, fifth, seventh, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E5, E7, E9> Tuple9<T1, T2, E3, T4, E5, T6, E7, T8, E9> x3579(@NotNull E3 e3, @NotNull E5 e5, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, e5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, fifth, seventh, and ninethelements are exchanged. 
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E4, E5, E7, E9> Tuple9<T1, T2, T3, E4, E5, T6, E7, T8, E9> x4579(@NotNull E4 e4, @NotNull E5 e5, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, e5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, sixth, seventh, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E6, E7, E9> Tuple9<E1, T2, T3, T4, T5, E6, E7, T8, E9> x1679(@NotNull E1 e1, @NotNull E6 e6, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, elem5, e6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, sixth, seventh, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E6, E7, E9> Tuple9<T1, E2, T3, T4, T5, E6, E7, T8, E9> x2679(@NotNull E2 e2, @NotNull E6 e6, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, elem5, e6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, sixth, seventh, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E6, E7, E9> Tuple9<T1, T2, E3, T4, T5, E6, E7, T8, E9> x3679(@NotNull E3 e3, @NotNull E6 e6, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, elem5, e6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, sixth, seventh, and ninethelements are exchanged. 
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E4, E6, E7, E9> Tuple9<T1, T2, T3, E4, T5, E6, E7, T8, E9> x4679(@NotNull E4 e4, @NotNull E6 e6, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, elem5, e6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fifth, sixth, seventh, and ninethelements are exchanged. 
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E5, E6, E7, E9> Tuple9<T1, T2, T3, T4, E5, E6, E7, T8, E9> x5679(@NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, e5, e6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E8, E9> Tuple9<E1, E2, T3, T4, T5, T6, T7, E8, E9> x1289(@NotNull E1 e1, @NotNull E2 e2, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, elem3, elem4, elem5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E3, E8, E9> Tuple9<E1, T2, E3, T4, T5, T6, T7, E8, E9> x1389(@NotNull E1 e1, @NotNull E3 e3, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, e3, elem4, elem5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, eighth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E3, E8, E9> Tuple9<T1, E2, E3, T4, T5, T6, T7, E8, E9> x2389(@NotNull E2 e2, @NotNull E3 e3, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, e3, elem4, elem5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E4, E8, E9> Tuple9<E1, T2, T3, E4, T5, T6, T7, E8, E9> x1489(@NotNull E1 e1, @NotNull E4 e4, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, e4, elem5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, eighth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E4, E8, E9> Tuple9<T1, E2, T3, E4, T5, T6, T7, E8, E9> x2489(@NotNull E2 e2, @NotNull E4 e4, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, e4, elem5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, eighth, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E4, E8, E9> Tuple9<T1, T2, E3, E4, T5, T6, T7, E8, E9> x3489(@NotNull E3 e3, @NotNull E4 e4, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, e4, elem5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, fifth, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E5, E8, E9> Tuple9<E1, T2, T3, T4, E5, T6, T7, E8, E9> x1589(@NotNull E1 e1, @NotNull E5 e5, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, e5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, fifth, eighth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E5, E8, E9> Tuple9<T1, E2, T3, T4, E5, T6, T7, E8, E9> x2589(@NotNull E2 e2, @NotNull E5 e5, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, e5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, fifth, eighth, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E5, E8, E9> Tuple9<T1, T2, E3, T4, E5, T6, T7, E8, E9> x3589(@NotNull E3 e3, @NotNull E5 e5, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, e5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, fifth, eighth, and ninethelements are exchanged. 
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E4, E5, E8, E9> Tuple9<T1, T2, T3, E4, E5, T6, T7, E8, E9> x4589(@NotNull E4 e4, @NotNull E5 e5, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, e5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, sixth, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E6, E8, E9> Tuple9<E1, T2, T3, T4, T5, E6, T7, E8, E9> x1689(@NotNull E1 e1, @NotNull E6 e6, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, elem5, e6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, sixth, eighth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E6, E8, E9> Tuple9<T1, E2, T3, T4, T5, E6, T7, E8, E9> x2689(@NotNull E2 e2, @NotNull E6 e6, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, elem5, e6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, sixth, eighth, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E6, E8, E9> Tuple9<T1, T2, E3, T4, T5, E6, T7, E8, E9> x3689(@NotNull E3 e3, @NotNull E6 e6, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, elem5, e6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, sixth, eighth, and ninethelements are exchanged. 
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E4, E6, E8, E9> Tuple9<T1, T2, T3, E4, T5, E6, T7, E8, E9> x4689(@NotNull E4 e4, @NotNull E6 e6, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, elem5, e6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fifth, sixth, eighth, and ninethelements are exchanged. 
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E5, E6, E8, E9> Tuple9<T1, T2, T3, T4, E5, E6, T7, E8, E9> x5689(@NotNull E5 e5, @NotNull E6 e6, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, e5, e6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, seventh, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E7, E8, E9> Tuple9<E1, T2, T3, T4, T5, T6, E7, E8, E9> x1789(@NotNull E1 e1, @NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, elem5, elem6, e7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, seventh, eighth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E7, E8, E9> Tuple9<T1, E2, T3, T4, T5, T6, E7, E8, E9> x2789(@NotNull E2 e2, @NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, elem5, elem6, e7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, seventh, eighth, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E7, E8, E9> Tuple9<T1, T2, E3, T4, T5, T6, E7, E8, E9> x3789(@NotNull E3 e3, @NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, elem5, elem6, e7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, seventh, eighth, and ninethelements are exchanged. 
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E4, E7, E8, E9> Tuple9<T1, T2, T3, E4, T5, T6, E7, E8, E9> x4789(@NotNull E4 e4, @NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, elem5, elem6, e7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fifth, seventh, eighth, and ninethelements are exchanged. 
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E5, E7, E8, E9> Tuple9<T1, T2, T3, T4, E5, T6, E7, E8, E9> x5789(@NotNull E5 e5, @NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, e5, elem6, e7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the sixth, seventh, eighth, and ninethelements are exchanged. 
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E6, E7, E8, E9> Tuple9<T1, T2, T3, T4, T5, E6, E7, E8, E9> x6789(@NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, elem5, e6, e7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, third, fourth, and fifthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   */
  @NotNull
  public <E1, E2, E3, E4, E5> Tuple9<E1, E2, E3, E4, E5, T6, T7, T8, T9> x12345(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5)  {
    return new Tuple9<>(e1, e2, e3, e4, e5, elem6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, third, fourth, and sixthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E1, E2, E3, E4, E6> Tuple9<E1, E2, E3, E4, T5, E6, T7, T8, T9> x12346(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4, @NotNull E6 e6)  {
    return new Tuple9<>(e1, e2, e3, e4, elem5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, third, fifth, and sixthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E1, E2, E3, E5, E6> Tuple9<E1, E2, E3, T4, E5, E6, T7, T8, T9> x12356(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3, @NotNull E5 e5, @NotNull E6 e6)  {
    return new Tuple9<>(e1, e2, e3, elem4, e5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fourth, fifth, and sixthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E1, E2, E4, E5, E6> Tuple9<E1, E2, T3, E4, E5, E6, T7, T8, T9> x12456(@NotNull E1 e1, @NotNull E2 e2, @NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6)  {
    return new Tuple9<>(e1, e2, elem3, e4, e5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fourth, fifth, and sixthelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E1, E3, E4, E5, E6> Tuple9<E1, T2, E3, E4, E5, E6, T7, T8, T9> x13456(@NotNull E1 e1, @NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6)  {
    return new Tuple9<>(e1, elem2, e3, e4, e5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fourth, fifth, and sixthelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   */
  @NotNull
  public <E2, E3, E4, E5, E6> Tuple9<T1, E2, E3, E4, E5, E6, T7, T8, T9> x23456(@NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6)  {
    return new Tuple9<>(elem1, e2, e3, e4, e5, e6, elem7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, third, fourth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E2, E3, E4, E7> Tuple9<E1, E2, E3, E4, T5, T6, E7, T8, T9> x12347(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4, @NotNull E7 e7)  {
    return new Tuple9<>(e1, e2, e3, e4, elem5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, third, fifth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E2, E3, E5, E7> Tuple9<E1, E2, E3, T4, E5, T6, E7, T8, T9> x12357(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3, @NotNull E5 e5, @NotNull E7 e7)  {
    return new Tuple9<>(e1, e2, e3, elem4, e5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fourth, fifth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E2, E4, E5, E7> Tuple9<E1, E2, T3, E4, E5, T6, E7, T8, T9> x12457(@NotNull E1 e1, @NotNull E2 e2, @NotNull E4 e4, @NotNull E5 e5, @NotNull E7 e7)  {
    return new Tuple9<>(e1, e2, elem3, e4, e5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fourth, fifth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E3, E4, E5, E7> Tuple9<E1, T2, E3, E4, E5, T6, E7, T8, T9> x13457(@NotNull E1 e1, @NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5, @NotNull E7 e7)  {
    return new Tuple9<>(e1, elem2, e3, e4, e5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fourth, fifth, and seventhelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E2, E3, E4, E5, E7> Tuple9<T1, E2, E3, E4, E5, T6, E7, T8, T9> x23457(@NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, e2, e3, e4, e5, elem6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, third, sixth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E2, E3, E6, E7> Tuple9<E1, E2, E3, T4, T5, E6, E7, T8, T9> x12367(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(e1, e2, e3, elem4, elem5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fourth, sixth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E2, E4, E6, E7> Tuple9<E1, E2, T3, E4, T5, E6, E7, T8, T9> x12467(@NotNull E1 e1, @NotNull E2 e2, @NotNull E4 e4, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(e1, e2, elem3, e4, elem5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fourth, sixth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E3, E4, E6, E7> Tuple9<E1, T2, E3, E4, T5, E6, E7, T8, T9> x13467(@NotNull E1 e1, @NotNull E3 e3, @NotNull E4 e4, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(e1, elem2, e3, e4, elem5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fourth, sixth, and seventhelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E2, E3, E4, E6, E7> Tuple9<T1, E2, E3, E4, T5, E6, E7, T8, T9> x23467(@NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, e2, e3, e4, elem5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fifth, sixth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E2, E5, E6, E7> Tuple9<E1, E2, T3, T4, E5, E6, E7, T8, T9> x12567(@NotNull E1 e1, @NotNull E2 e2, @NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(e1, e2, elem3, elem4, e5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fifth, sixth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E3, E5, E6, E7> Tuple9<E1, T2, E3, T4, E5, E6, E7, T8, T9> x13567(@NotNull E1 e1, @NotNull E3 e3, @NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(e1, elem2, e3, elem4, e5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fifth, sixth, and seventhelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E2, E3, E5, E6, E7> Tuple9<T1, E2, E3, T4, E5, E6, E7, T8, T9> x23567(@NotNull E2 e2, @NotNull E3 e3, @NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, e2, e3, elem4, e5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, fifth, sixth, and seventhelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E1, E4, E5, E6, E7> Tuple9<E1, T2, T3, E4, E5, E6, E7, T8, T9> x14567(@NotNull E1 e1, @NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(e1, elem2, elem3, e4, e5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, fifth, sixth, and seventhelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E2, E4, E5, E6, E7> Tuple9<T1, E2, T3, E4, E5, E6, E7, T8, T9> x24567(@NotNull E2 e2, @NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, e2, elem3, e4, e5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, fifth, sixth, and seventhelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   */
  @NotNull
  public <E3, E4, E5, E6, E7> Tuple9<T1, T2, E3, E4, E5, E6, E7, T8, T9> x34567(@NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7)  {
    return new Tuple9<>(elem1, elem2, e3, e4, e5, e6, e7, elem8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, third, fourth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E2, E3, E4, E8> Tuple9<E1, E2, E3, E4, T5, T6, T7, E8, T9> x12348(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4, @NotNull E8 e8)  {
    return new Tuple9<>(e1, e2, e3, e4, elem5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, third, fifth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E2, E3, E5, E8> Tuple9<E1, E2, E3, T4, E5, T6, T7, E8, T9> x12358(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3, @NotNull E5 e5, @NotNull E8 e8)  {
    return new Tuple9<>(e1, e2, e3, elem4, e5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fourth, fifth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E2, E4, E5, E8> Tuple9<E1, E2, T3, E4, E5, T6, T7, E8, T9> x12458(@NotNull E1 e1, @NotNull E2 e2, @NotNull E4 e4, @NotNull E5 e5, @NotNull E8 e8)  {
    return new Tuple9<>(e1, e2, elem3, e4, e5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fourth, fifth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E3, E4, E5, E8> Tuple9<E1, T2, E3, E4, E5, T6, T7, E8, T9> x13458(@NotNull E1 e1, @NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, e3, e4, e5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fourth, fifth, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E3, E4, E5, E8> Tuple9<T1, E2, E3, E4, E5, T6, T7, E8, T9> x23458(@NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, e3, e4, e5, elem6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, third, sixth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E2, E3, E6, E8> Tuple9<E1, E2, E3, T4, T5, E6, T7, E8, T9> x12368(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(e1, e2, e3, elem4, elem5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fourth, sixth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E2, E4, E6, E8> Tuple9<E1, E2, T3, E4, T5, E6, T7, E8, T9> x12468(@NotNull E1 e1, @NotNull E2 e2, @NotNull E4 e4, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(e1, e2, elem3, e4, elem5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fourth, sixth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E3, E4, E6, E8> Tuple9<E1, T2, E3, E4, T5, E6, T7, E8, T9> x13468(@NotNull E1 e1, @NotNull E3 e3, @NotNull E4 e4, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, e3, e4, elem5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fourth, sixth, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E3, E4, E6, E8> Tuple9<T1, E2, E3, E4, T5, E6, T7, E8, T9> x23468(@NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, e3, e4, elem5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fifth, sixth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E2, E5, E6, E8> Tuple9<E1, E2, T3, T4, E5, E6, T7, E8, T9> x12568(@NotNull E1 e1, @NotNull E2 e2, @NotNull E5 e5, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(e1, e2, elem3, elem4, e5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fifth, sixth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E3, E5, E6, E8> Tuple9<E1, T2, E3, T4, E5, E6, T7, E8, T9> x13568(@NotNull E1 e1, @NotNull E3 e3, @NotNull E5 e5, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, e3, elem4, e5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fifth, sixth, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E3, E5, E6, E8> Tuple9<T1, E2, E3, T4, E5, E6, T7, E8, T9> x23568(@NotNull E2 e2, @NotNull E3 e3, @NotNull E5 e5, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, e3, elem4, e5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, fifth, sixth, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E4, E5, E6, E8> Tuple9<E1, T2, T3, E4, E5, E6, T7, E8, T9> x14568(@NotNull E1 e1, @NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, elem3, e4, e5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, fifth, sixth, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E4, E5, E6, E8> Tuple9<T1, E2, T3, E4, E5, E6, T7, E8, T9> x24568(@NotNull E2 e2, @NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, elem3, e4, e5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, fifth, sixth, and eighthelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E3, E4, E5, E6, E8> Tuple9<T1, T2, E3, E4, E5, E6, T7, E8, T9> x34568(@NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, e3, e4, e5, e6, elem7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, third, seventh, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E2, E3, E7, E8> Tuple9<E1, E2, E3, T4, T5, T6, E7, E8, T9> x12378(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(e1, e2, e3, elem4, elem5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fourth, seventh, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E2, E4, E7, E8> Tuple9<E1, E2, T3, E4, T5, T6, E7, E8, T9> x12478(@NotNull E1 e1, @NotNull E2 e2, @NotNull E4 e4, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(e1, e2, elem3, e4, elem5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fourth, seventh, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E3, E4, E7, E8> Tuple9<E1, T2, E3, E4, T5, T6, E7, E8, T9> x13478(@NotNull E1 e1, @NotNull E3 e3, @NotNull E4 e4, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, e3, e4, elem5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fourth, seventh, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E3, E4, E7, E8> Tuple9<T1, E2, E3, E4, T5, T6, E7, E8, T9> x23478(@NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, e3, e4, elem5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fifth, seventh, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E2, E5, E7, E8> Tuple9<E1, E2, T3, T4, E5, T6, E7, E8, T9> x12578(@NotNull E1 e1, @NotNull E2 e2, @NotNull E5 e5, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(e1, e2, elem3, elem4, e5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fifth, seventh, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E3, E5, E7, E8> Tuple9<E1, T2, E3, T4, E5, T6, E7, E8, T9> x13578(@NotNull E1 e1, @NotNull E3 e3, @NotNull E5 e5, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, e3, elem4, e5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fifth, seventh, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E3, E5, E7, E8> Tuple9<T1, E2, E3, T4, E5, T6, E7, E8, T9> x23578(@NotNull E2 e2, @NotNull E3 e3, @NotNull E5 e5, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, e3, elem4, e5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, fifth, seventh, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E4, E5, E7, E8> Tuple9<E1, T2, T3, E4, E5, T6, E7, E8, T9> x14578(@NotNull E1 e1, @NotNull E4 e4, @NotNull E5 e5, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, elem3, e4, e5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, fifth, seventh, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E4, E5, E7, E8> Tuple9<T1, E2, T3, E4, E5, T6, E7, E8, T9> x24578(@NotNull E2 e2, @NotNull E4 e4, @NotNull E5 e5, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, elem3, e4, e5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, fifth, seventh, and eighthelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E3, E4, E5, E7, E8> Tuple9<T1, T2, E3, E4, E5, T6, E7, E8, T9> x34578(@NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, e3, e4, e5, elem6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, sixth, seventh, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E2, E6, E7, E8> Tuple9<E1, E2, T3, T4, T5, E6, E7, E8, T9> x12678(@NotNull E1 e1, @NotNull E2 e2, @NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(e1, e2, elem3, elem4, elem5, e6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, sixth, seventh, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E3, E6, E7, E8> Tuple9<E1, T2, E3, T4, T5, E6, E7, E8, T9> x13678(@NotNull E1 e1, @NotNull E3 e3, @NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, e3, elem4, elem5, e6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, sixth, seventh, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E3, E6, E7, E8> Tuple9<T1, E2, E3, T4, T5, E6, E7, E8, T9> x23678(@NotNull E2 e2, @NotNull E3 e3, @NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, e3, elem4, elem5, e6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, sixth, seventh, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E4, E6, E7, E8> Tuple9<E1, T2, T3, E4, T5, E6, E7, E8, T9> x14678(@NotNull E1 e1, @NotNull E4 e4, @NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, elem3, e4, elem5, e6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, sixth, seventh, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E4, E6, E7, E8> Tuple9<T1, E2, T3, E4, T5, E6, E7, E8, T9> x24678(@NotNull E2 e2, @NotNull E4 e4, @NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, elem3, e4, elem5, e6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, sixth, seventh, and eighthelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E3, E4, E6, E7, E8> Tuple9<T1, T2, E3, E4, T5, E6, E7, E8, T9> x34678(@NotNull E3 e3, @NotNull E4 e4, @NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, e3, e4, elem5, e6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, fifth, sixth, seventh, and eighthelements are exchanged. 
   * @param e1 new first element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E1, E5, E6, E7, E8> Tuple9<E1, T2, T3, T4, E5, E6, E7, E8, T9> x15678(@NotNull E1 e1, @NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, e5, e6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the second, fifth, sixth, seventh, and eighthelements are exchanged. 
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E2, E5, E6, E7, E8> Tuple9<T1, E2, T3, T4, E5, E6, E7, E8, T9> x25678(@NotNull E2 e2, @NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, e5, e6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the third, fifth, sixth, seventh, and eighthelements are exchanged. 
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E3, E5, E6, E7, E8> Tuple9<T1, T2, E3, T4, E5, E6, E7, E8, T9> x35678(@NotNull E3 e3, @NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, e5, e6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, fifth, sixth, seventh, and eighthelements are exchanged. 
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   */
  @NotNull
  public <E4, E5, E6, E7, E8> Tuple9<T1, T2, T3, E4, E5, E6, E7, E8, T9> x45678(@NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, e5, e6, e7, e8, elem9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, third, fourth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E3, E4, E9> Tuple9<E1, E2, E3, E4, T5, T6, T7, T8, E9> x12349(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, e3, e4, elem5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, third, fifth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E3, E5, E9> Tuple9<E1, E2, E3, T4, E5, T6, T7, T8, E9> x12359(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3, @NotNull E5 e5, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, e3, elem4, e5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fourth, fifth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E4, E5, E9> Tuple9<E1, E2, T3, E4, E5, T6, T7, T8, E9> x12459(@NotNull E1 e1, @NotNull E2 e2, @NotNull E4 e4, @NotNull E5 e5, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, elem3, e4, e5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fourth, fifth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E3, E4, E5, E9> Tuple9<E1, T2, E3, E4, E5, T6, T7, T8, E9> x13459(@NotNull E1 e1, @NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, e3, e4, e5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fourth, fifth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E3, E4, E5, E9> Tuple9<T1, E2, E3, E4, E5, T6, T7, T8, E9> x23459(@NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, e3, e4, e5, elem6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, third, sixth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E3, E6, E9> Tuple9<E1, E2, E3, T4, T5, E6, T7, T8, E9> x12369(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, e3, elem4, elem5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fourth, sixth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E4, E6, E9> Tuple9<E1, E2, T3, E4, T5, E6, T7, T8, E9> x12469(@NotNull E1 e1, @NotNull E2 e2, @NotNull E4 e4, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, elem3, e4, elem5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fourth, sixth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E3, E4, E6, E9> Tuple9<E1, T2, E3, E4, T5, E6, T7, T8, E9> x13469(@NotNull E1 e1, @NotNull E3 e3, @NotNull E4 e4, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, e3, e4, elem5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fourth, sixth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E3, E4, E6, E9> Tuple9<T1, E2, E3, E4, T5, E6, T7, T8, E9> x23469(@NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, e3, e4, elem5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fifth, sixth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E5, E6, E9> Tuple9<E1, E2, T3, T4, E5, E6, T7, T8, E9> x12569(@NotNull E1 e1, @NotNull E2 e2, @NotNull E5 e5, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, elem3, elem4, e5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fifth, sixth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E3, E5, E6, E9> Tuple9<E1, T2, E3, T4, E5, E6, T7, T8, E9> x13569(@NotNull E1 e1, @NotNull E3 e3, @NotNull E5 e5, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, e3, elem4, e5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fifth, sixth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E3, E5, E6, E9> Tuple9<T1, E2, E3, T4, E5, E6, T7, T8, E9> x23569(@NotNull E2 e2, @NotNull E3 e3, @NotNull E5 e5, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, e3, elem4, e5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, fifth, sixth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E4, E5, E6, E9> Tuple9<E1, T2, T3, E4, E5, E6, T7, T8, E9> x14569(@NotNull E1 e1, @NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, e4, e5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, fifth, sixth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E4, E5, E6, E9> Tuple9<T1, E2, T3, E4, E5, E6, T7, T8, E9> x24569(@NotNull E2 e2, @NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, e4, e5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, fifth, sixth, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E4, E5, E6, E9> Tuple9<T1, T2, E3, E4, E5, E6, T7, T8, E9> x34569(@NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, e4, e5, e6, elem7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, third, seventh, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E3, E7, E9> Tuple9<E1, E2, E3, T4, T5, T6, E7, T8, E9> x12379(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, e3, elem4, elem5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fourth, seventh, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E4, E7, E9> Tuple9<E1, E2, T3, E4, T5, T6, E7, T8, E9> x12479(@NotNull E1 e1, @NotNull E2 e2, @NotNull E4 e4, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, elem3, e4, elem5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fourth, seventh, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E3, E4, E7, E9> Tuple9<E1, T2, E3, E4, T5, T6, E7, T8, E9> x13479(@NotNull E1 e1, @NotNull E3 e3, @NotNull E4 e4, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, e3, e4, elem5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fourth, seventh, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E3, E4, E7, E9> Tuple9<T1, E2, E3, E4, T5, T6, E7, T8, E9> x23479(@NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, e3, e4, elem5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fifth, seventh, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E5, E7, E9> Tuple9<E1, E2, T3, T4, E5, T6, E7, T8, E9> x12579(@NotNull E1 e1, @NotNull E2 e2, @NotNull E5 e5, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, elem3, elem4, e5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fifth, seventh, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E3, E5, E7, E9> Tuple9<E1, T2, E3, T4, E5, T6, E7, T8, E9> x13579(@NotNull E1 e1, @NotNull E3 e3, @NotNull E5 e5, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, e3, elem4, e5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fifth, seventh, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E3, E5, E7, E9> Tuple9<T1, E2, E3, T4, E5, T6, E7, T8, E9> x23579(@NotNull E2 e2, @NotNull E3 e3, @NotNull E5 e5, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, e3, elem4, e5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, fifth, seventh, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E4, E5, E7, E9> Tuple9<E1, T2, T3, E4, E5, T6, E7, T8, E9> x14579(@NotNull E1 e1, @NotNull E4 e4, @NotNull E5 e5, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, e4, e5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, fifth, seventh, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E4, E5, E7, E9> Tuple9<T1, E2, T3, E4, E5, T6, E7, T8, E9> x24579(@NotNull E2 e2, @NotNull E4 e4, @NotNull E5 e5, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, e4, e5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, fifth, seventh, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E4, E5, E7, E9> Tuple9<T1, T2, E3, E4, E5, T6, E7, T8, E9> x34579(@NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, e4, e5, elem6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, sixth, seventh, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E6, E7, E9> Tuple9<E1, E2, T3, T4, T5, E6, E7, T8, E9> x12679(@NotNull E1 e1, @NotNull E2 e2, @NotNull E6 e6, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, elem3, elem4, elem5, e6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, sixth, seventh, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E3, E6, E7, E9> Tuple9<E1, T2, E3, T4, T5, E6, E7, T8, E9> x13679(@NotNull E1 e1, @NotNull E3 e3, @NotNull E6 e6, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, e3, elem4, elem5, e6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, sixth, seventh, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E3, E6, E7, E9> Tuple9<T1, E2, E3, T4, T5, E6, E7, T8, E9> x23679(@NotNull E2 e2, @NotNull E3 e3, @NotNull E6 e6, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, e3, elem4, elem5, e6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, sixth, seventh, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E4, E6, E7, E9> Tuple9<E1, T2, T3, E4, T5, E6, E7, T8, E9> x14679(@NotNull E1 e1, @NotNull E4 e4, @NotNull E6 e6, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, e4, elem5, e6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, sixth, seventh, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E4, E6, E7, E9> Tuple9<T1, E2, T3, E4, T5, E6, E7, T8, E9> x24679(@NotNull E2 e2, @NotNull E4 e4, @NotNull E6 e6, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, e4, elem5, e6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, sixth, seventh, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E4, E6, E7, E9> Tuple9<T1, T2, E3, E4, T5, E6, E7, T8, E9> x34679(@NotNull E3 e3, @NotNull E4 e4, @NotNull E6 e6, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, e4, elem5, e6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, fifth, sixth, seventh, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E5, E6, E7, E9> Tuple9<E1, T2, T3, T4, E5, E6, E7, T8, E9> x15679(@NotNull E1 e1, @NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, e5, e6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, fifth, sixth, seventh, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E5, E6, E7, E9> Tuple9<T1, E2, T3, T4, E5, E6, E7, T8, E9> x25679(@NotNull E2 e2, @NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, e5, e6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, fifth, sixth, seventh, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E5, E6, E7, E9> Tuple9<T1, T2, E3, T4, E5, E6, E7, T8, E9> x35679(@NotNull E3 e3, @NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, e5, e6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, fifth, sixth, seventh, and ninethelements are exchanged. 
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E4, E5, E6, E7, E9> Tuple9<T1, T2, T3, E4, E5, E6, E7, T8, E9> x45679(@NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, e5, e6, e7, elem8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, third, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e3 new third element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E3, E8, E9> Tuple9<E1, E2, E3, T4, T5, T6, T7, E8, E9> x12389(@NotNull E1 e1, @NotNull E2 e2, @NotNull E3 e3, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, e3, elem4, elem5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fourth, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E4, E8, E9> Tuple9<E1, E2, T3, E4, T5, T6, T7, E8, E9> x12489(@NotNull E1 e1, @NotNull E2 e2, @NotNull E4 e4, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, elem3, e4, elem5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fourth, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E3, E4, E8, E9> Tuple9<E1, T2, E3, E4, T5, T6, T7, E8, E9> x13489(@NotNull E1 e1, @NotNull E3 e3, @NotNull E4 e4, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, e3, e4, elem5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fourth, eighth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E3, E4, E8, E9> Tuple9<T1, E2, E3, E4, T5, T6, T7, E8, E9> x23489(@NotNull E2 e2, @NotNull E3 e3, @NotNull E4 e4, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, e3, e4, elem5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, fifth, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E5, E8, E9> Tuple9<E1, E2, T3, T4, E5, T6, T7, E8, E9> x12589(@NotNull E1 e1, @NotNull E2 e2, @NotNull E5 e5, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, elem3, elem4, e5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, fifth, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E3, E5, E8, E9> Tuple9<E1, T2, E3, T4, E5, T6, T7, E8, E9> x13589(@NotNull E1 e1, @NotNull E3 e3, @NotNull E5 e5, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, e3, elem4, e5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, fifth, eighth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E3, E5, E8, E9> Tuple9<T1, E2, E3, T4, E5, T6, T7, E8, E9> x23589(@NotNull E2 e2, @NotNull E3 e3, @NotNull E5 e5, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, e3, elem4, e5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, fifth, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E4, E5, E8, E9> Tuple9<E1, T2, T3, E4, E5, T6, T7, E8, E9> x14589(@NotNull E1 e1, @NotNull E4 e4, @NotNull E5 e5, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, e4, e5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, fifth, eighth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E4, E5, E8, E9> Tuple9<T1, E2, T3, E4, E5, T6, T7, E8, E9> x24589(@NotNull E2 e2, @NotNull E4 e4, @NotNull E5 e5, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, e4, e5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, fifth, eighth, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E4, E5, E8, E9> Tuple9<T1, T2, E3, E4, E5, T6, T7, E8, E9> x34589(@NotNull E3 e3, @NotNull E4 e4, @NotNull E5 e5, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, e4, e5, elem6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, sixth, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E6, E8, E9> Tuple9<E1, E2, T3, T4, T5, E6, T7, E8, E9> x12689(@NotNull E1 e1, @NotNull E2 e2, @NotNull E6 e6, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, elem3, elem4, elem5, e6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, sixth, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E3, E6, E8, E9> Tuple9<E1, T2, E3, T4, T5, E6, T7, E8, E9> x13689(@NotNull E1 e1, @NotNull E3 e3, @NotNull E6 e6, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, e3, elem4, elem5, e6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, sixth, eighth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E3, E6, E8, E9> Tuple9<T1, E2, E3, T4, T5, E6, T7, E8, E9> x23689(@NotNull E2 e2, @NotNull E3 e3, @NotNull E6 e6, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, e3, elem4, elem5, e6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, sixth, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E4, E6, E8, E9> Tuple9<E1, T2, T3, E4, T5, E6, T7, E8, E9> x14689(@NotNull E1 e1, @NotNull E4 e4, @NotNull E6 e6, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, e4, elem5, e6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, sixth, eighth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E4, E6, E8, E9> Tuple9<T1, E2, T3, E4, T5, E6, T7, E8, E9> x24689(@NotNull E2 e2, @NotNull E4 e4, @NotNull E6 e6, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, e4, elem5, e6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, sixth, eighth, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E4, E6, E8, E9> Tuple9<T1, T2, E3, E4, T5, E6, T7, E8, E9> x34689(@NotNull E3 e3, @NotNull E4 e4, @NotNull E6 e6, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, e4, elem5, e6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, fifth, sixth, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E5, E6, E8, E9> Tuple9<E1, T2, T3, T4, E5, E6, T7, E8, E9> x15689(@NotNull E1 e1, @NotNull E5 e5, @NotNull E6 e6, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, e5, e6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, fifth, sixth, eighth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E5, E6, E8, E9> Tuple9<T1, E2, T3, T4, E5, E6, T7, E8, E9> x25689(@NotNull E2 e2, @NotNull E5 e5, @NotNull E6 e6, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, e5, e6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, fifth, sixth, eighth, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E5, E6, E8, E9> Tuple9<T1, T2, E3, T4, E5, E6, T7, E8, E9> x35689(@NotNull E3 e3, @NotNull E5 e5, @NotNull E6 e6, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, e5, e6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, fifth, sixth, eighth, and ninethelements are exchanged. 
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E4, E5, E6, E8, E9> Tuple9<T1, T2, T3, E4, E5, E6, T7, E8, E9> x45689(@NotNull E4 e4, @NotNull E5 e5, @NotNull E6 e6, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, e5, e6, elem7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, second, seventh, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e2 new second element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E2> type of exchanged second element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E2, E7, E8, E9> Tuple9<E1, E2, T3, T4, T5, T6, E7, E8, E9> x12789(@NotNull E1 e1, @NotNull E2 e2, @NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, e2, elem3, elem4, elem5, elem6, e7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, third, seventh, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e3 new third element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E3> type of exchanged third element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E3, E7, E8, E9> Tuple9<E1, T2, E3, T4, T5, T6, E7, E8, E9> x13789(@NotNull E1 e1, @NotNull E3 e3, @NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, e3, elem4, elem5, elem6, e7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, third, seventh, eighth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e3 new third element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E3> type of exchanged third element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E3, E7, E8, E9> Tuple9<T1, E2, E3, T4, T5, T6, E7, E8, E9> x23789(@NotNull E2 e2, @NotNull E3 e3, @NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, e3, elem4, elem5, elem6, e7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, fourth, seventh, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E4, E7, E8, E9> Tuple9<E1, T2, T3, E4, T5, T6, E7, E8, E9> x14789(@NotNull E1 e1, @NotNull E4 e4, @NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, e4, elem5, elem6, e7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, fourth, seventh, eighth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E4, E7, E8, E9> Tuple9<T1, E2, T3, E4, T5, T6, E7, E8, E9> x24789(@NotNull E2 e2, @NotNull E4 e4, @NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, e4, elem5, elem6, e7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, fourth, seventh, eighth, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e4 new fourth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E4> type of exchanged fourth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E4, E7, E8, E9> Tuple9<T1, T2, E3, E4, T5, T6, E7, E8, E9> x34789(@NotNull E3 e3, @NotNull E4 e4, @NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, e4, elem5, elem6, e7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, fifth, seventh, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E5, E7, E8, E9> Tuple9<E1, T2, T3, T4, E5, T6, E7, E8, E9> x15789(@NotNull E1 e1, @NotNull E5 e5, @NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, e5, elem6, e7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, fifth, seventh, eighth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E5, E7, E8, E9> Tuple9<T1, E2, T3, T4, E5, T6, E7, E8, E9> x25789(@NotNull E2 e2, @NotNull E5 e5, @NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, e5, elem6, e7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, fifth, seventh, eighth, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E5, E7, E8, E9> Tuple9<T1, T2, E3, T4, E5, T6, E7, E8, E9> x35789(@NotNull E3 e3, @NotNull E5 e5, @NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, e5, elem6, e7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, fifth, seventh, eighth, and ninethelements are exchanged. 
   * @param e4 new fourth element
   * @param e5 new fifth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E5> type of exchanged fifth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E4, E5, E7, E8, E9> Tuple9<T1, T2, T3, E4, E5, T6, E7, E8, E9> x45789(@NotNull E4 e4, @NotNull E5 e5, @NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, e5, elem6, e7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the first, sixth, seventh, eighth, and ninethelements are exchanged. 
   * @param e1 new first element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E1> type of exchanged first element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E1, E6, E7, E8, E9> Tuple9<E1, T2, T3, T4, T5, E6, E7, E8, E9> x16789(@NotNull E1 e1, @NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(e1, elem2, elem3, elem4, elem5, e6, e7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the second, sixth, seventh, eighth, and ninethelements are exchanged. 
   * @param e2 new second element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E2> type of exchanged second element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E2, E6, E7, E8, E9> Tuple9<T1, E2, T3, T4, T5, E6, E7, E8, E9> x26789(@NotNull E2 e2, @NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, e2, elem3, elem4, elem5, e6, e7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the third, sixth, seventh, eighth, and ninethelements are exchanged. 
   * @param e3 new third element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E3> type of exchanged third element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E3, E6, E7, E8, E9> Tuple9<T1, T2, E3, T4, T5, E6, E7, E8, E9> x36789(@NotNull E3 e3, @NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, e3, elem4, elem5, e6, e7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fourth, sixth, seventh, eighth, and ninethelements are exchanged. 
   * @param e4 new fourth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E4> type of exchanged fourth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E4, E6, E7, E8, E9> Tuple9<T1, T2, T3, E4, T5, E6, E7, E8, E9> x46789(@NotNull E4 e4, @NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, e4, elem5, e6, e7, e8, e9);
  }

  /**
   * Create a 9-tuple from this one where the fifth, sixth, seventh, eighth, and ninethelements are exchanged. 
   * @param e5 new fifth element
   * @param e6 new sixth element
   * @param e7 new seventh element
   * @param e8 new eighth element
   * @param e9 new nineth element
   * @return tuple with exchanged elements
   * @param <E5> type of exchanged fifth element
   * @param <E6> type of exchanged sixth element
   * @param <E7> type of exchanged seventh element
   * @param <E8> type of exchanged eighth element
   * @param <E9> type of exchanged nineth element
   */
  @NotNull
  public <E5, E6, E7, E8, E9> Tuple9<T1, T2, T3, T4, E5, E6, E7, E8, E9> x56789(@NotNull E5 e5, @NotNull E6 e6, @NotNull E7 e7, @NotNull E8 e8, @NotNull E9 e9)  {
    return new Tuple9<>(elem1, elem2, elem3, elem4, e5, e6, e7, e8, e9);
  }

  @NotNull
  @Override
  public String toString()
  {
    return ITuple9.toString("Tuple9", this);
  }

}
